@@ -5,13 +5,17 @@ from catalyst.core import Callback, CallbackOrder, IRunner
 from catalyst.registry import REGISTRY
 
 
-def _tuple_wrapper(transform: Callable):
-    def wrapper(*inputs):
-        """Function wrapper for tuple output"""
-        output = transform(*inputs)
-        return (output,)
+class _TupleWrapper:
+    """Function wrapper for tuple output"""
 
-    return wrapper
+    def __init__(self, transform: Callable) -> None:
+        """Init."""
+        self.transform = transform
+
+    def __call__(self, *inputs) -> Any:
+        """Call."""
+        output = self.transform(*inputs)
+        return (output,)
 
 
 class BatchTransformCallback(Callback):
@@ -19,15 +23,14 @@ class BatchTransformCallback(Callback):
     Preprocess your batch with specified function.
 
     Args:
-        transform (Callable, str): Function to apply. If string will get function from registry.
-        scope (str): ``"on_batch_end"`` (post-processing model output) or
+        transform: Function to apply. If string will get function from registry.
+        scope: ``"on_batch_end"`` (post-processing model output) or
             ``"on_batch_start"`` (pre-processing model input).
-        input_key (Union[List[str], str], optional): Keys in batch dict to apply function.
-            Defaults to ``None``.
-        output_key (Union[List[str], str], optional): Keys for output.
+        input_key: Keys in batch dict to apply function. Defaults to ``None``.
+        output_key: Keys for output.
             If None then will apply function inplace to ``keys_to_apply``.
             Defaults to ``None``.
-        transform_kwargs (Dict[str, Any]): Kwargs for transform.
+        transform_kwargs: Kwargs for transform.
 
     Raises:
         TypeError: When keys is not str or a list.
@@ -68,29 +71,18 @@ class BatchTransformCallback(Callback):
                 verbose=True,
                 callbacks=[
                     dl.BatchTransformCallback(
-                        input_key="logits", output_key="scores", transform="F.sigmoid",
+                        input_key="logits", output_key="scores", transform="F.sigmoid"
                     ),
                     dl.CriterionCallback(
                         input_key="logits", target_key="targets", metric_key="loss"
                     ),
-            # uncomment for extra metrics:
-            #       dl.AUCCallback(
-            #           input_key="scores", target_key="targets"
-            #       ),
-            #       dl.HitrateCallback(
-            #           input_key="scores", target_key="targets", topk_args=(1, 3, 5)
-            #       ),
-            #       dl.MRRCallback(
-            #           input_key="scores", target_key="targets", topk_args=(1, 3, 5)
-            #       ),
-            #       dl.MAPCallback(input_key="scores", target_key="targets", topk_args=(1, 3, 5)),
-            #       dl.NDCGCallback(
-            #           input_key="scores", target_key="targets", topk_args=(1, 3, 5)
-            #       ),
                     dl.OptimizerCallback(metric_key="loss"),
                     dl.SchedulerCallback(),
                     dl.CheckpointCallback(
-                        logdir="./logs", loader_key="valid", metric_key="map01", minimize=False
+                        logdir="./logs",
+                        loader_key="valid",
+                        metric_key="map01",
+                        minimize=False
                     ),
                 ]
             )
@@ -108,12 +100,14 @@ class BatchTransformCallback(Callback):
                     accuracy01, accuracy03 = metrics.accuracy(
                         logits, batch["targets"], topk=(1, 3)
                     )
-                    self.batch_metrics.update(
-                        {"loss": loss, "accuracy01": accuracy01, "accuracy03": accuracy03}
-                    )
+                    self.batch_metrics.update({
+                        "loss": loss,
+                        "accuracy01":accuracy01,
+                        "accuracy03": accuracy03
+                    })
 
                     if self.is_train_loader:
-                        loss.backward()
+                        self.engine.backward(loss)
                         self.optimizer.step()
                         self.optimizer.zero_grad()
 
@@ -123,7 +117,10 @@ class BatchTransformCallback(Callback):
                     self.dataset = dataset
 
                 def __getitem__(self, item):
-                    return {"features": self.dataset[item][0], "targets": self.dataset[item][1]}
+                    return {
+                        "features": self.dataset[item][0],
+                        "targets": self.dataset[item][1]
+                    }
 
                 def __len__(self):
                     return len(self.dataset)
@@ -134,13 +131,13 @@ class BatchTransformCallback(Callback):
             loaders = {
                 "train": DataLoader(
                     MnistDataset(
-                        MNIST(os.getcwd(), train=False, download=True, transform=ToTensor())
+                        MNIST(os.getcwd(), train=False)
                     ),
                     batch_size=32,
                 ),
                 "valid": DataLoader(
                     MnistDataset(
-                        MNIST(os.getcwd(), train=False, download=True, transform=ToTensor())
+                        MNIST(os.getcwd(), train=False)
                     ),
                     batch_size=32,
                 ),
@@ -164,7 +161,9 @@ class BatchTransformCallback(Callback):
                 check=True,
                 callbacks=[
                     BatchTransformCallback(
-                        transform=transrorms, scope="on_batch_start", input_key="features"
+                        transform=transrorms,
+                        scope="on_batch_start",
+                        input_key="features"
                     )
                 ],
             )
@@ -193,16 +192,15 @@ class BatchTransformCallback(Callback):
         Preprocess your batch with specified function.
 
         Args:
-            transform (Callable, str): Function to apply.
+            transform: Function to apply.
                 If string will get function from registry.
-            scope (str): ``"on_batch_end"`` (post-processing model output) or
+            scope: ``"on_batch_end"`` (post-processing model output) or
                 ``"on_batch_start"`` (pre-processing model input).
-            input_key (Union[List[str], str], optional): Keys in batch dict to apply function.
-                Defaults to ``None``.
-            output_key (Union[List[str], str], optional): Keys for output.
+            input_key: Keys in batch dict to apply function. Defaults to ``None``.
+            output_key: Keys for output.
                 If None then will apply function inplace to ``keys_to_apply``.
                 Defaults to ``None``.
-            transform_kwargs (Dict[str, Any]): Kwargs for transform.
+            transform_kwargs: Kwargs for transform.
 
         Raises:
             TypeError: When keys is not str or a list.
@@ -225,17 +223,21 @@ class BatchTransformCallback(Callback):
         output_key = output_key or input_key
         if output_key is not None:
             if input_key is None:
-                raise TypeError("You should define input_key in " "case if output_key is not None")
+                raise TypeError(
+                    "You should define input_key in " "case if output_key is not None"
+                )
             if not isinstance(output_key, (list, str)):
                 raise TypeError("output key should be str or a list of str.")
             if isinstance(output_key, str):
                 output_key = [output_key]
-                transform = _tuple_wrapper(transform)
+                transform = _TupleWrapper(transform)
 
         if isinstance(scope, str) and scope in ["on_batch_end", "on_batch_start"]:
             self.scope = scope
         else:
-            raise TypeError('Expected scope to be on of the ["on_batch_end", "on_batch_start"]')
+            raise TypeError(
+                'Expected scope to be on of the ["on_batch_end", "on_batch_start"]'
+            )
         self.input_key = input_key
         self.output_key = output_key
         self.transform = transform
@@ -243,26 +245,20 @@ class BatchTransformCallback(Callback):
     def _handle_value(self, runner):
         batch_in = [runner.batch[key] for key in self.input_key]
         batch_out = self.transform(*batch_in)
-        runner.batch.update(**{key: value for key, value in zip(self.output_key, batch_out)})
+        runner.batch.update(
+            **{key: value for key, value in zip(self.output_key, batch_out)}
+        )
 
     def _handle_key_value(self, runner):
         runner.batch = self.transform(runner.batch)
 
     def on_batch_start(self, runner: "IRunner") -> None:
-        """On batch start action.
-
-        Args:
-            runner: runner for the experiment.
-        """
+        """Event handler."""
         if self.scope == "on_batch_start":
             self._handle_batch(runner)
 
     def on_batch_end(self, runner: "IRunner") -> None:
-        """On batch end action.
-
-        Args:
-            runner: runner for the experiment.
-        """
+        """Event handler."""
         if self.scope == "on_batch_end":
             self._handle_batch(runner)
 
