@@ -1,8 +1,8 @@
-from typing import Any, Callable, Dict, List, TYPE_CHECKING, Union
+from typing import Callable, Dict, List, TYPE_CHECKING, Union
 
 import torch
 
-from catalyst.core.callback import Callback, CallbackNode, CallbackOrder
+from catalyst.core.callback import Callback, CallbackOrder
 
 if TYPE_CHECKING:
     from catalyst.core.runner import IRunner
@@ -33,7 +33,8 @@ class MetricAggregationCallback(Callback):
         scope: type of metric. Must be either ``batch`` or ``loader``
         multiplier: scale factor for the aggregated metric.
 
-    Python example - loss is a weighted sum of cross entropy loss and binary cross entropy loss:
+    Python example - loss is a weighted sum of cross entropy loss
+    and binary cross entropy loss:
 
     .. code-block:: python
 
@@ -52,7 +53,10 @@ class MetricAggregationCallback(Callback):
 
         # model, criterion, optimizer, scheduler
         model = torch.nn.Linear(num_features, num_classes)
-        criterion = {"ce": torch.nn.CrossEntropyLoss(), "bce": torch.nn.BCEWithLogitsLoss()}
+        criterion = {
+            "ce": torch.nn.CrossEntropyLoss(),
+            "bce": torch.nn.BCEWithLogitsLoss()
+        }
         optimizer = torch.optim.Adam(model.parameters())
         scheduler = torch.optim.lr_scheduler.MultiStepLR(optimizer, [2])
 
@@ -121,7 +125,7 @@ class MetricAggregationCallback(Callback):
         multiplier: float = 1.0,
     ) -> None:
         """Init."""
-        super().__init__(order=CallbackOrder.metric_aggregation, node=CallbackNode.all)
+        super().__init__(order=CallbackOrder.metric_aggregation)
 
         if metric_key is None or not isinstance(metric_key, str):
             raise ValueError("prefix must be str")
@@ -141,7 +145,8 @@ class MetricAggregationCallback(Callback):
                 )
         elif not callable(mode):
             raise NotImplementedError(
-                "mode must be `sum`, `mean` " "or `weighted_sum` or `weighted_mean` or be Callable"
+                "mode must be `sum`, `mean` "
+                "or `weighted_sum` or `weighted_mean` or be Callable"
             )
 
         assert scope in ("batch", "loader")
@@ -159,32 +164,43 @@ class MetricAggregationCallback(Callback):
             self.aggregation_fn = _sum_aggregation
             if mode == "weighted_mean":
                 weights_sum = sum(metrics.items())
-                self.metrics = {key: weight / weights_sum for key, weight in metrics.items()}
+                self.metrics = {
+                    key: weight / weights_sum for key, weight in metrics.items()
+                }
         elif mode == "mean":
             self.aggregation_fn = _mean_aggregation
         elif callable(mode):
             self.aggregation_fn = mode
 
-    def _preprocess(self, metrics: Any) -> List[float]:
+    def _get_metrics_list(self, metrics: Dict) -> List[float]:
         if self.metrics is not None:
             try:
                 if self.mode == "weighted_sum":
-                    result = [metrics[key] * value for key, value in self.metrics.items()]
+                    result = [
+                        metrics[key] * value for key, value in self.metrics.items()
+                    ]
                 else:
                     result = [metrics[key] for key in self.metrics]
             except KeyError:
                 raise KeyError(f"Could not found required key out of {metrics.keys()}")
         else:
             result = list(metrics.values())
-        result = [metric.float() for metric in result]
         return result
 
-    def _process_metrics(self, metrics: Dict, runner: "IRunner") -> None:
+    def _process_metrics(self, scope: str, metrics: Dict, runner: "IRunner") -> None:
         if callable(self.mode):
             metric_aggregated = self.aggregation_fn(metrics, runner) * self.multiplier
         else:
-            metrics_processed = self._preprocess(metrics)
-            metric_aggregated = self.aggregation_fn(metrics_processed) * self.multiplier
+            metrics_list = self._get_metrics_list(metrics)
+            metrics_list = [
+                torch.tensor(v, device=runner.engine.device, dtype=torch.float32)
+                if not isinstance(v, torch.Tensor)
+                else v.float()
+                for v in metrics_list
+            ]
+            metric_aggregated = self.aggregation_fn(metrics_list) * self.multiplier
+        if scope == "loader":
+            metric_aggregated = float(metric_aggregated)
         metrics[self.metric_key] = metric_aggregated
 
     def on_batch_end(self, runner: "IRunner") -> None:
@@ -193,8 +209,9 @@ class MetricAggregationCallback(Callback):
         Args:
             runner: current runner
         """
+        # import ipdb; ipdb.set_trace()
         if self.scope == "batch":
-            self._process_metrics(runner.batch_metrics, runner)
+            self._process_metrics("batch", runner.batch_metrics, runner)
 
     def on_loader_end(self, runner: "IRunner") -> None:
         """Computes the metric and add it to the loader metrics.
@@ -202,9 +219,7 @@ class MetricAggregationCallback(Callback):
         Args:
             runner: current runner
         """
-        self._process_metrics(runner.loader_metrics, runner)
+        self._process_metrics("loader", runner.loader_metrics, runner)
 
 
-__all__ = [
-    "MetricAggregationCallback",
-]
+__all__ = ["MetricAggregationCallback"]
