@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import Iterable, Union
 
 import torch
 
@@ -13,11 +13,8 @@ class AccuracyCallback(BatchMetricCallback):
     Args:
         input_key: input key to use for metric calculation, specifies our `y_pred`
         target_key: output key to use for metric calculation, specifies our `y_true`
-        topk_args: specifies which accuracy@K to log:
-            [1] - accuracy
-            [1, 3] - accuracy at 1 and 3
-            [1, 3, 5] - accuracy at 1, 3 and 5
-        num_classes: number of classes to calculate ``topk_args`` if ``accuracy_args`` is None
+        topk: specifies which accuracy@K to log
+        num_classes: number of classes to calculate ``topk`` if ``accuracy_args`` is None
         log_on_batch: boolean flag to log computed metrics every batch
         prefix: metric prefix
         suffix: metric suffix
@@ -48,7 +45,10 @@ class AccuracyCallback(BatchMetricCallback):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss"
         )
         runner.train(
             model=model,
@@ -73,17 +73,29 @@ class AccuracyCallback(BatchMetricCallback):
             ],
         )
 
+    .. note::
+        Metric names depending on input parameters:
+
+        - ``topk = None`` ---> see \
+            :py:mod:`catalyst.metrics.functional._misc.get_default_topk`
+        - ``topk = (1,)`` ---> ``"accuracy01"``
+        - ``topk = (1, 3)`` ---> ``"accuracy01"``, ``"accuracy03"``
+        - ``topk = (1, 3, 5)`` ---> ``"accuracy01"``, ``"accuracy03"``, ``"accuracy05"``
+
+        You can find them in ``runner.batch_metrics``, ``runner.loader_metrics`` or
+        ``runner.epoch_metrics``.
+
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
         self,
         input_key: str,
         target_key: str,
-        topk_args: List[int] = None,
+        topk: Iterable[int] = None,
         num_classes: int = None,
         log_on_batch: bool = True,
         prefix: str = None,
@@ -92,7 +104,10 @@ class AccuracyCallback(BatchMetricCallback):
         """Init."""
         super().__init__(
             metric=AccuracyMetric(
-                topk_args=topk_args, num_classes=num_classes, prefix=prefix, suffix=suffix
+                topk=topk,
+                num_classes=num_classes,
+                prefix=prefix,
+                suffix=suffix,
             ),
             input_key=input_key,
             target_key=target_key,
@@ -138,7 +153,10 @@ class MultilabelAccuracyCallback(BatchMetricCallback):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss"
         )
         runner.train(
             model=model,
@@ -162,7 +180,7 @@ class MultilabelAccuracyCallback(BatchMetricCallback):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -176,7 +194,9 @@ class MultilabelAccuracyCallback(BatchMetricCallback):
     ):
         """Init."""
         super().__init__(
-            metric=MultilabelAccuracyMetric(threshold=threshold, prefix=prefix, suffix=suffix),
+            metric=MultilabelAccuracyMetric(
+                threshold=threshold, prefix=prefix, suffix=suffix
+            ),
             input_key=input_key,
             target_key=target_key,
             log_on_batch=log_on_batch,
