@@ -2,6 +2,7 @@ from typing import List, Optional
 
 from catalyst.callbacks.metric import BatchMetricCallback
 from catalyst.metrics._segmentation import DiceMetric, IOUMetric, TrevskyMetric
+from catalyst.settings import SETTINGS
 
 
 class IOUCallback(BatchMetricCallback):
@@ -16,6 +17,8 @@ class IOUCallback(BatchMetricCallback):
         class_names: class names
         threshold: threshold for outputs binarization
         log_on_batch: boolean flag to log computed metrics every batch
+        compute_per_class_metrics: boolean flag to compute per-class metrics
+            (default: SETTINGS.compute_per_class_metrics or False).
         prefix: metric prefix
         suffix: metric suffix
 
@@ -29,8 +32,7 @@ class IOUCallback(BatchMetricCallback):
         from torch.utils.data import DataLoader
         from catalyst import dl
         from catalyst.data import ToTensor
-        from catalyst.contrib.datasets import MNIST
-        from catalyst.contrib.nn import IoULoss
+        from catalyst.contrib import MNIST, IoULoss
 
 
         model = nn.Sequential(
@@ -46,7 +48,7 @@ class IOUCallback(BatchMetricCallback):
                 batch_size=32
             ),
             "valid": DataLoader(
-                MNIST(os.getcwd(), train=False, download=True, transform=ToTensor()),
+                MNIST(os.getcwd(), train=False),
                 batch_size=32
             ),
         }
@@ -56,10 +58,15 @@ class IOUCallback(BatchMetricCallback):
                 x = batch[self._input_key]
                 x_noise = (x + torch.rand_like(x)).clamp_(0, 1)
                 x_ = self.model(x_noise)
-                self.batch = {self._input_key: x, self._output_key: x_, self._target_key: x}
+                self.batch = {
+                    self._input_key: x, self._output_key: x_, self._target_key: x
+                }
 
         runner = CustomRunner(
-            input_key="features", output_key="scores", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="scores",
+            target_key="targets",
+            loss_key="loss"
         )
         # model training
         runner.train(
@@ -83,7 +90,7 @@ class IOUCallback(BatchMetricCallback):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -95,6 +102,7 @@ class IOUCallback(BatchMetricCallback):
         class_names: Optional[List[str]] = None,
         threshold: Optional[float] = None,
         log_on_batch: bool = True,
+        compute_per_class_metrics: bool = SETTINGS.compute_per_class_metrics,
         prefix: str = None,
         suffix: str = None,
     ):
@@ -105,6 +113,7 @@ class IOUCallback(BatchMetricCallback):
                 weights=weights,
                 class_names=class_names,
                 threshold=threshold,
+                compute_per_class_metrics=compute_per_class_metrics,
                 prefix=prefix,
                 suffix=suffix,
             ),
@@ -126,6 +135,8 @@ class DiceCallback(BatchMetricCallback):
         class_names: class names
         threshold: threshold for outputs binarization
         log_on_batch: boolean flag to log computed metrics every batch
+        compute_per_class_metrics: boolean flag to compute per-class metrics
+            (default: SETTINGS.compute_per_class_metrics or False).
         prefix: metric prefix
         suffix: metric suffix
 
@@ -139,8 +150,7 @@ class DiceCallback(BatchMetricCallback):
         from torch.utils.data import DataLoader
         from catalyst import dl
         from catalyst.data import ToTensor
-        from catalyst.contrib.datasets import MNIST
-        from catalyst.contrib.nn import IoULoss
+        from catalyst.contrib import MNIST, IoULoss
 
 
         model = nn.Sequential(
@@ -156,7 +166,7 @@ class DiceCallback(BatchMetricCallback):
                 batch_size=32
             ),
             "valid": DataLoader(
-                MNIST(os.getcwd(), train=False, download=True, transform=ToTensor()),
+                MNIST(os.getcwd(), train=False),
                 batch_size=32
             ),
         }
@@ -166,10 +176,15 @@ class DiceCallback(BatchMetricCallback):
                 x = batch[self._input_key]
                 x_noise = (x + torch.rand_like(x)).clamp_(0, 1)
                 x_ = self.model(x_noise)
-                self.batch = {self._input_key: x, self._output_key: x_, self._target_key: x}
+                self.batch = {
+                    self._input_key: x, self._output_key: x_, self._target_key: x
+                }
 
         runner = CustomRunner(
-            input_key="features", output_key="scores", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="scores",
+            target_key="targets",
+            loss_key="loss"
         )
         # model training
         runner.train(
@@ -193,7 +208,7 @@ class DiceCallback(BatchMetricCallback):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -205,6 +220,7 @@ class DiceCallback(BatchMetricCallback):
         class_names: Optional[List[str]] = None,
         threshold: Optional[float] = None,
         log_on_batch: bool = True,
+        compute_per_class_metrics: bool = SETTINGS.compute_per_class_metrics,
         prefix: str = None,
         suffix: str = None,
     ):
@@ -215,6 +231,7 @@ class DiceCallback(BatchMetricCallback):
                 weights=weights,
                 class_names=class_names,
                 threshold=threshold,
+                compute_per_class_metrics=compute_per_class_metrics,
                 prefix=prefix,
                 suffix=suffix,
             ),
@@ -240,6 +257,8 @@ class TrevskyCallback(BatchMetricCallback):
         class_names: class names
         threshold: threshold for outputs binarization
         log_on_batch: boolean flag to log computed metrics every batch
+        compute_per_class_metrics: boolean flag to compute per-class metrics
+            (default: SETTINGS.compute_per_class_metrics or False).
         prefix: metric prefix
         suffix: metric suffix
 
@@ -252,10 +271,7 @@ class TrevskyCallback(BatchMetricCallback):
         from torch import nn
         from torch.utils.data import DataLoader
         from catalyst import dl
-        from catalyst.data import ToTensor
-        from catalyst.contrib.datasets import MNIST
-        from catalyst.contrib.nn import IoULoss
-
+        from catalyst.contrib import MNIST, IoULoss
 
         model = nn.Sequential(
             nn.Conv2d(1, 1, 3, 1, 1), nn.ReLU(),
@@ -266,11 +282,11 @@ class TrevskyCallback(BatchMetricCallback):
 
         loaders = {
             "train": DataLoader(
-                MNIST(os.getcwd(), train=True, download=True, transform=ToTensor()),
+                MNIST(os.getcwd(), train=True),
                 batch_size=32
             ),
             "valid": DataLoader(
-                MNIST(os.getcwd(), train=False, download=True, transform=ToTensor()),
+                MNIST(os.getcwd(), train=False),
                 batch_size=32
             ),
         }
@@ -280,10 +296,15 @@ class TrevskyCallback(BatchMetricCallback):
                 x = batch[self._input_key]
                 x_noise = (x + torch.rand_like(x)).clamp_(0, 1)
                 x_ = self.model(x_noise)
-                self.batch = {self._input_key: x, self._output_key: x_, self._target_key: x}
+                self.batch = {
+                    self._input_key: x, self._output_key: x_, self._target_key: x
+                }
 
         runner = CustomRunner(
-            input_key="features", output_key="scores", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="scores",
+            target_key="targets",
+            loss_key="loss"
         )
         # model training
         runner.train(
@@ -307,7 +328,7 @@ class TrevskyCallback(BatchMetricCallback):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -321,6 +342,7 @@ class TrevskyCallback(BatchMetricCallback):
         class_names: Optional[List[str]] = None,
         threshold: Optional[float] = None,
         log_on_batch: bool = True,
+        compute_per_class_metrics: bool = SETTINGS.compute_per_class_metrics,
         prefix: str = None,
         suffix: str = None,
     ):
@@ -333,6 +355,7 @@ class TrevskyCallback(BatchMetricCallback):
                 weights=weights,
                 class_names=class_names,
                 threshold=threshold,
+                compute_per_class_metrics=compute_per_class_metrics,
                 prefix=prefix,
                 suffix=suffix,
             ),
