@@ -24,9 +24,7 @@ class PeriodicLoaderCallback(Callback):
 
     .. code-block:: python
 
-        from catalyst.dl import (
-            SupervisedRunner, PeriodicLoaderRunnerCallback,
-        )
+        from catalyst.dl import SupervisedRunner, PeriodicLoaderCallback
         runner = SupervisedRunner()
         runner.train(
             ...
@@ -39,7 +37,7 @@ class PeriodicLoaderCallback(Callback):
             ...
             callbacks=[
                 ...
-                PeriodicLoaderRunnerCallback(
+                PeriodicLoaderCallback(
                     train_additional=2,
                     valid=3,
                     valid_additional=5
@@ -52,13 +50,18 @@ class PeriodicLoaderCallback(Callback):
     """
 
     def __init__(
-        self, valid_loader_key: str, valid_metric_key: str, minimize: bool = True, **kwargs
+        self,
+        valid_loader_key: str,
+        valid_metric_key: str,
+        minimize: bool,
+        **kwargs,
     ):
         """Init."""
         super().__init__(order=CallbackOrder.internal)
+        # @TODO: make valid_loader optional
 
-        self.valid_loader: str = valid_loader_key
-        self.valid_metric: str = valid_metric_key
+        self.valid_loader_key: str = valid_loader_key
+        self.valid_metric_key: str = valid_metric_key
         self.minimize_metric: bool = minimize
         self.loaders: Mapping[str, DataLoader] = OrderedDict()
 
@@ -66,14 +69,15 @@ class PeriodicLoaderCallback(Callback):
         for loader, period in kwargs.items():
             if not isinstance(period, (int, float)):
                 raise TypeError(
-                    "Expected loader period type is int/float " f"but got {type(period)}!"
+                    "Expected loader period type is int/float "
+                    f"but got {type(period)}!"
                 )
             period = int(period)
             if period < 0:
                 raise ValueError(f"Period should be >= 0, but got - {period}!")
             self.loader_periods[loader] = period
 
-    def on_stage_start(self, runner: "IRunner") -> None:
+    def on_experiment_start(self, runner: "IRunner") -> None:
         """Collect information about loaders.
 
         Args:
@@ -85,24 +89,29 @@ class PeriodicLoaderCallback(Callback):
         # store pointers to data loader objects
         for name, loader in runner.loaders.items():
             self.loaders[name] = loader
-        # stage validation loader
-        is_loaders_match = all(loader in runner.loaders for loader in self.loader_periods.keys())
+        # experiment validation loader
+        is_loaders_match = all(
+            loader in runner.loaders for loader in self.loader_periods.keys()
+        )
         is_same_loaders_number = len(self.loader_periods) == len(runner.loaders)
         if is_same_loaders_number and is_loaders_match:
             # find potential epoch with zero loaders
             zero_loaders_epochs = list(
                 filter(
-                    lambda n: all((p == 0 or n % p != 0) for p in self.loader_periods.values()),
-                    range(1, runner.stage_epoch_len + 1),
+                    lambda n: all(
+                        (p == 0 or n % p != 0) for p in self.loader_periods.values()
+                    ),
+                    range(1, runner.num_epochs + 1),
                 )
             )
             if len(zero_loaders_epochs) > 0:
                 epoch_with_err = zero_loaders_epochs[0]
                 raise ValueError(f"There will be no loaders in epoch {epoch_with_err}!")
 
-        if self.loader_periods.get(self.valid_loader, 1) < 1:
+        if self.loader_periods.get(self.valid_loader_key, 1) < 1:
             raise ValueError(
-                f"Period for a validation loader ('{self.valid_loader}') " "should be > 0!"
+                f"Period for a validation loader ('{self.valid_loader_key}') "
+                "should be > 0!"
             )
 
     def on_epoch_start(self, runner: "IRunner") -> None:
@@ -121,16 +130,16 @@ class PeriodicLoaderCallback(Callback):
         Raises:
             ValueError: if there are no loaders in epoch
         """
-        epoch_num = runner.stage_epoch_step
+        epoch_step = runner.epoch_step
         # loaders to use in current epoch
         epoch_loaders = OrderedDict()
         for name, loader in self.loaders.items():
             period = self.loader_periods.get(name, 1)
             # ignore loaders where period - 0
-            if period > 0 and epoch_num % period == 0:
+            if period > 0 and epoch_step % period == 0:
                 epoch_loaders[name] = loader
         if len(epoch_loaders) == 0:
-            raise ValueError(f"There is no loaders in epoch {epoch_num}!")
+            raise ValueError(f"There is no loaders in epoch {epoch_step}!")
         # first_loader = next(iter(epoch_loaders.keys()))
         # runner.valid_loader = (
         #     self.valid_loader if self.valid_loader in epoch_loaders else first_loader
@@ -143,9 +152,11 @@ class PeriodicLoaderCallback(Callback):
         Args:
             runner: current runner
         """
-        if self.valid_loader not in runner.loaders:
-            runner.epoch_metrics[self.valid_loader] = {
-                self.valid_metric: float("+inf") if self.minimize_metric else float("-inf")
+        if self.valid_loader_key not in runner.loaders:
+            runner.epoch_metrics[self.valid_loader_key] = {
+                self.valid_metric_key: float("+inf")
+                if self.minimize_metric
+                else float("-inf")
             }
 
 
