@@ -13,7 +13,7 @@ from collections import namedtuple
 import locale
 import os
 import re
-import subprocess  # noqa: S404
+import subprocess
 import sys
 
 try:
@@ -86,7 +86,7 @@ def parse_args():
 def run(command):
     """Returns (return-code, stdout, stderr)"""
     p = subprocess.Popen(
-        command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True,  # noqa: S602
+        command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True
     )
     output, err = p.communicate()
     rc = p.returncode
@@ -150,7 +150,9 @@ def get_nvidia_driver_version(run_lambda):
     """Returns nvidia driver version"""
     if get_platform() == "darwin":
         cmd = "kextstat | grep -i cuda"
-        return run_and_parse_first_match(run_lambda, cmd, r"com[.]nvidia[.]CUDA [(](.*?)[)]")
+        return run_and_parse_first_match(
+            run_lambda, cmd, r"com[.]nvidia[.]CUDA [(](.*?)[)]"
+        )
     smi = get_nvidia_smi()
     return run_and_parse_first_match(run_lambda, smi, r"Driver Version: (.*?) ")
 
@@ -178,7 +180,7 @@ def get_running_cuda_version(run_lambda):
 def get_cudnn_version(run_lambda):
     """This will return a list of libcudnn.so; it"s hard to tell which one is being used"""
     if get_platform() == "win32":
-        cudnn_cmd = "where /R '%CUDA_PATH%\\bin' cudnn*.dll"  # noqa: WPS342
+        cudnn_cmd = "where /R '%CUDA_PATH%\\bin' cudnn*.dll"
     elif get_platform() == "darwin":
         # CUDA libraries and drivers can be found in /usr/local/cuda/. See
         # https://docs.nvidia.com/cuda/cuda-installation-guide-mac-os-x/index.html#install
@@ -215,8 +217,8 @@ def get_nvidia_smi():
     smi = "nvidia-smi"
     if get_platform() == "win32":
         smi = (
-            "'C:\\Program Files\\NVIDIA Corporation\\NVSMI\\%s'" % smi  # noqa: WPS342, W505, E501
-        )
+            "'C:\\Program Files\\NVIDIA Corporation\\NVSMI\\%s'" % smi
+        )  # noqa: W505, E501
     return smi
 
 
@@ -251,7 +253,9 @@ def get_lsb_version(run_lambda):
 
 def check_release_file(run_lambda):
     """Checks release file"""
-    return run_and_parse_first_match(run_lambda, "cat /etc/*-release", r"PRETTY_NAME='(.*)'")
+    return run_and_parse_first_match(
+        run_lambda, "cat /etc/*-release", r"PRETTY_NAME='(.*)'"
+    )
 
 
 def get_os(run_lambda):
@@ -410,10 +414,12 @@ def pretty_str(envinfo):  # noqa: C901
             return "\n{}\n".format(string)
         return string
 
-    mutable_dict = envinfo._asdict()  # noqa: WPS437
+    mutable_dict = envinfo._asdict()
 
     # If nvidia_gpu_models is multiline, start on the next line
-    mutable_dict["nvidia_gpu_models"] = maybe_start_on_next_line(envinfo.nvidia_gpu_models)
+    mutable_dict["nvidia_gpu_models"] = maybe_start_on_next_line(
+        envinfo.nvidia_gpu_models
+    )
 
     # If the machine doesn"t have CUDA, report some fields as "No CUDA"
     dynamic_cuda_fields = [
@@ -425,7 +431,11 @@ def pretty_str(envinfo):  # noqa: C901
     all_dynamic_cuda_fields_missing = all(
         mutable_dict[field] is None for field in dynamic_cuda_fields
     )
-    if TORCH_AVAILABLE and not torch.cuda.is_available() and all_dynamic_cuda_fields_missing:
+    if (
+        TORCH_AVAILABLE
+        and not torch.cuda.is_available()
+        and all_dynamic_cuda_fields_missing
+    ):
         for field in all_cuda_fields:
             mutable_dict[field] = "No CUDA"
         if envinfo.cuda_compiled_version is None:
@@ -449,7 +459,9 @@ def pretty_str(envinfo):  # noqa: C901
             mutable_dict["pip_packages"], "[{}] ".format(envinfo.pip_version)
         )
     if mutable_dict["conda_packages"]:
-        mutable_dict["conda_packages"] = prepend(mutable_dict["conda_packages"], "[conda] ")
+        mutable_dict["conda_packages"] = prepend(
+            mutable_dict["conda_packages"], "[conda] "
+        )
     return env_info_fmt.format(**mutable_dict)
 
 
