@@ -18,34 +18,22 @@ if SETTINGS.cv_required:
         mimread,
     )
 
+from catalyst.contrib.utils.numpy import get_one_hot
+
 if SETTINGS.ml_required:
-    from catalyst.contrib.utils.pandas import (
-        dataframe_to_list,
-        folds_to_list,
-        split_dataframe_train_test,
-        split_dataframe_on_folds,
-        split_dataframe_on_stratified_folds,
-        split_dataframe_on_column_folds,
-        map_dataframe,
-        separate_tags,
-        get_dataset_labeling,
-        split_dataframe,
-        balance_classes,
-        create_dataset,
-        split_dataset_train_test,
-        create_dataframe,
-    )
-
-
-from catalyst.contrib.utils.parallel import (
-    parallel_imap,
-    tqdm_parallel_imap,
-    get_pool,
-)
-
+    from catalyst.contrib.utils.report import get_classification_report
 
 from catalyst.contrib.utils.serialization import deserialize, serialize
 
+from catalyst.contrib.utils.swa import average_weights, get_averaged_weights_by_path_mask
+
+from catalyst.contrib.utils.torch import (
+    get_optimal_inner_init,
+    outer_init,
+    get_network_output,
+    trim_tensors,
+)
+
 if SETTINGS.ml_required:
     from catalyst.contrib.utils.thresholds import (
         get_baseline_thresholds,
