@@ -1,21 +1,19 @@
 import logging
-import os
 import pickle
 
-logger = logging.getLogger(__name__)
+from catalyst.settings import SETTINGS
 
-try:
-    import pyarrow
+LOGGER = logging.getLogger(__name__)
 
-    PYARROW_ENABLED = True
-except ImportError as ex:
-    if os.environ.get("USE_PYARROW", "0") == "1":
-        logger.warning(
+if SETTINGS.use_pyarrow:
+    try:
+        import pyarrow
+    except ImportError as ex:
+        LOGGER.warning(
             "pyarrow not available, switching to pickle. "
             "To install pyarrow, run `pip install pyarrow`."
         )
         raise ex
-    PYARROW_ENABLED = False
 
 
 def pyarrow_serialize(data):
@@ -30,7 +28,7 @@ def pyarrow_serialize(data):
     return pyarrow.serialize(data).to_buffer().to_pybytes()
 
 
-def pyarrow_deserialize(data):
+def pyarrow_deserialize(bytes):
     """Deserialize bytes into an object using pyarrow.
 
     Args:
@@ -39,7 +37,7 @@ def pyarrow_deserialize(data):
     Returns:
         Returns a value deserialized from the bytes-like object.
     """
-    return pyarrow.deserialize(data)
+    return pyarrow.deserialize(bytes)
 
 
 def pickle_serialize(data):
@@ -54,7 +52,7 @@ def pickle_serialize(data):
     return pickle.dumps(data)
 
 
-def pickle_deserialize(data):
+def pickle_deserialize(bytes):
     """Deserialize bytes into an object using pickle.
 
     Args:
@@ -63,10 +61,10 @@ def pickle_deserialize(data):
     Returns:
         Returns a value deserialized from the bytes-like object.
     """
-    return pickle.loads(data)
+    return pickle.loads(bytes)
 
 
-if PYARROW_ENABLED:
+if SETTINGS.use_pyarrow:
     serialize = pyarrow_serialize
     deserialize = pyarrow_deserialize
 else:
