@@ -5,12 +5,13 @@ from operator import itemgetter
 import random
 
 import numpy as np
-import torch
-from torch.utils.data import DistributedSampler
-from torch.utils.data.sampler import BatchSampler, Sampler
 
-from catalyst.data.dataset.torch import DatasetFromSampler
-from catalyst.utils.misc import find_value_ids
+from torch.utils.data import DistributedSampler
+from torch.utils.data.sampler import Sampler
+
+from catalyst.data.dataset import DatasetFromSampler
+
+LOGGER = logging.getLogger(__name__)
 
 
 class BalanceClassSampler(Sampler):
@@ -35,7 +36,7 @@ class BalanceClassSampler(Sampler):
         train_data = MNIST(os.getcwd(), train=True, download=True, transform=ToTensor())
         train_labels = train_data.targets.cpu().numpy().tolist()
         train_sampler = BalanceClassSampler(train_labels, mode=5000)
-        valid_data = MNIST(os.getcwd(), train=False, download=True, transform=ToTensor())
+        valid_data = MNIST(os.getcwd(), train=False)
 
         loaders = {
             "train": DataLoader(train_data, sampler=train_sampler, batch_size=32),
@@ -70,14 +71,17 @@ class BalanceClassSampler(Sampler):
         samples_per_class = {label: (labels == label).sum() for label in set(labels)}
 
         self.lbl2idx = {
-            label: np.arange(len(labels))[labels == label].tolist() for label in set(labels)
+            label: np.arange(len(labels))[labels == label].tolist()
+            for label in set(labels)
         }
 
         if isinstance(mode, str):
             assert mode in ["downsampling", "upsampling"]
 
         if isinstance(mode, int) or mode == "upsampling":
-            samples_per_class = mode if isinstance(mode, int) else max(samples_per_class.values())
+            samples_per_class = (
+                mode if isinstance(mode, int) else max(samples_per_class.values())
+            )
         else:
             samples_per_class = min(samples_per_class.values())
 
@@ -87,8 +91,8 @@ class BalanceClassSampler(Sampler):
 
     def __iter__(self) -> Iterator[int]:
         """
-        Yields:
-            indices of stratified sample
+        Returns:
+            iterator of indices of stratified sample
         """
         indices = []
         for key in sorted(self.lbl2idx):
@@ -109,123 +113,8 @@ class BalanceClassSampler(Sampler):
         return self.length
 
 
-class BalanceBatchSampler(Sampler):
-    """
-    This kind of sampler can be used for both metric learning and
-    classification task.
-
-    Sampler with the given strategy for the C unique classes dataset:
-    - Selection P of C classes for the 1st batch
-    - Selection K instances for each class for the 1st batch
-    - Selection P of C - P remaining classes for 2nd batch
-    - Selection K instances for each class for the 2nd batch
-    - ...
-    The epoch ends when there are no classes left.
-    So, the batch sise is P * K except the last one.
-
-    Thus, in each epoch, all the classes will be selected once, but this
-    does not mean that all the instances will be selected during the epoch.
-
-    One of the purposes of this sampler is to be used for
-    forming triplets and pos/neg pairs inside the batch.
-    To guarante existance of these pairs in the batch,
-    P and K should be > 1. (1)
-
-    Behavior in corner cases:
-    - If a class does not contain K instances,
-    a choice will be made with repetition.
-    - If C % P == 1 then one of the classes should be dropped
-    otherwise statement (1) will not be met.
-
-    This type of sampling can be found in the classical paper of Person Re-Id,
-    where P equals 32 and K equals 4:
-    `In Defense of the Triplet Loss for Person Re-Identification`_.
-
-    Args:
-        labels: list of classes labeles for each elem in the dataset
-        p: number of classes in a batch, should be > 1
-        k: number of instances of each class in a batch, should be > 1
-
-    .. _In Defense of the Triplet Loss for Person Re-Identification:
-        https://arxiv.org/abs/1703.07737
-    """
-
-    def __init__(self, labels: Union[List[int], np.ndarray], p: int, k: int):
-        """Sampler initialisation."""
-        super().__init__(self)
-        classes = set(labels)
-
-        assert isinstance(p, int) and isinstance(k, int)
-        assert (1 < p <= len(classes)) and (1 < k)
-        assert all(
-            n > 1 for n in Counter(labels).values()
-        ), "Each class shoud contain at least 2 instances to fit (1)"
-
-        self._labels = np.array(labels)
-        self._p = p
-        self._k = k
-
-        self._batch_size = self._p * self._k
-        self._classes = classes
-
-        # to satisfy statement (1)
-        num_classes = len(self._classes)
-        if num_classes % self._p == 1:
-            self._num_epoch_classes = num_classes - 1
-        else:
-            self._num_epoch_classes = num_classes
-
-    @property
-    def batch_size(self) -> int:
-        """
-        Returns:
-            this value should be used in DataLoader as batch size
-        """
-        return self._batch_size
-
-    @property
-    def batches_in_epoch(self) -> int:
-        """
-        Returns:
-            number of batches in an epoch
-        """
-        return int(np.ceil(self._num_epoch_classes / self._p))
-
-    def __len__(self) -> int:
-        """
-        Returns:
-            number of samples in an epoch
-        """
-        return self._num_epoch_classes * self._k
-
-    def __iter__(self) -> Iterator[int]:
-        """
-        Returns:
-            indeces for sampling dataset elems during an epoch
-        """
-        inds = []
-
-        for cls_id in random.sample(self._classes, self._num_epoch_classes):
-            all_cls_inds = find_value_ids(self._labels, cls_id)
-
-            # we've checked in __init__ that this value must be > 1
-            num_samples_exists = len(all_cls_inds)
-
-            if num_samples_exists < self._k:
-                selected_inds = random.sample(all_cls_inds, k=num_samples_exists) + random.choices(
-                    all_cls_inds, k=self._k - num_samples_exists
-                )
-            else:
-                selected_inds = random.sample(all_cls_inds, k=self._k)
-
-            inds.extend(selected_inds)
-
-        return iter(inds)
-
-
 class BatchBalanceClassSampler(Sampler):
     """
-    BatchSampler version of BalanceBatchSampler.
     This kind of sampler can be used for both metric learning and classification task.
 
     BatchSampler with the given strategy for the C unique classes dataset:
@@ -264,10 +153,11 @@ class BatchBalanceClassSampler(Sampler):
         from catalyst.data import ToTensor, BatchBalanceClassSampler
         from catalyst.contrib.datasets import MNIST
 
-        train_data = MNIST(os.getcwd(), train=True, download=True, transform=ToTensor())
+        train_data = MNIST(os.getcwd(), train=True, download=True)
         train_labels = train_data.targets.cpu().numpy().tolist()
-        train_sampler = BatchBalanceClassSampler(train_labels, num_classes=10, num_samples=4)
-        valid_data = MNIST(os.getcwd(), train=False, download=True, transform=ToTensor())
+        train_sampler = BatchBalanceClassSampler(
+            train_labels, num_classes=10, num_samples=4)
+        valid_data = MNIST(os.getcwd(), train=False)
 
         loaders = {
             "train": DataLoader(train_data, batch_sampler=train_sampler),
@@ -318,7 +208,8 @@ class BatchBalanceClassSampler(Sampler):
         self._batch_size = self._num_classes * self._num_samples
         self._num_batches = num_batches or len(labels) // self._batch_size
         self.lbl2idx = {
-            label: np.arange(len(labels))[labels == label].tolist() for label in set(labels)
+            label: np.arange(len(labels))[labels == label].tolist()
+            for label in set(labels)
         }
 
     @property
@@ -441,8 +332,7 @@ class DynamicBalanceClassSampler(Sampler):
         self.min_class_size = min(samples_per_class.values())
 
         if self.min_class_size < 100 and not ignore_warning:
-            logger = logging.getLogger(__name__)
-            logger.warning(
+            LOGGER.warning(
                 f"the smallest class contains only"
                 f" {self.min_class_size} examples. At the end of"
                 f" training, epochs will contain only"
@@ -454,7 +344,8 @@ class DynamicBalanceClassSampler(Sampler):
             key: value / self.min_class_size for key, value in samples_per_class.items()
         }
         self.label2idxes = {
-            label: np.arange(len(labels))[labels == label].tolist() for label in set(labels)
+            label: np.arange(len(labels))[labels == label].tolist()
+            for label in set(labels)
         }
 
         if isinstance(mode, int):
@@ -466,10 +357,7 @@ class DynamicBalanceClassSampler(Sampler):
         self._update()
 
     def _update(self) -> None:
-        """
-        Update d coefficients
-        Returns: None
-        """
+        """Update d coefficients."""
         current_d = {
             key: min(value ** self._exp_scheduler(), self.max_d)
             for key, value in self.original_d.items()
@@ -486,8 +374,8 @@ class DynamicBalanceClassSampler(Sampler):
 
     def __iter__(self) -> Iterator[int]:
         """
-        Yields:
-            indices of stratified sample
+        Returns:
+            iterator of indices of stratified sample
         """
         indices = []
         for key in sorted(self.label2idxes):
@@ -533,7 +421,11 @@ class MiniEpochSampler(Sampler):
     """
 
     def __init__(
-        self, data_len: int, mini_epoch_len: int, drop_last: bool = False, shuffle: str = None,
+        self,
+        data_len: int,
+        mini_epoch_len: int,
+        drop_last: bool = False,
+        shuffle: str = None,
     ):
         """Sampler initialisation."""
         super().__init__(None)
@@ -558,7 +450,8 @@ class MiniEpochSampler(Sampler):
 
         if not (shuffle is None or shuffle in ["per_mini_epoch", "per_epoch"]):
             raise ValueError(
-                "Shuffle must be one of ['per_mini_epoch', 'per_epoch']. " + f"Got {shuffle}"
+                "Shuffle must be one of ['per_mini_epoch', 'per_epoch']. "
+                + f"Got {shuffle}"
             )
         self.shuffle_type = shuffle
 
@@ -571,7 +464,9 @@ class MiniEpochSampler(Sampler):
                 self.indices = self._indices
                 np.random.shuffle(self.indices)
             else:
-                self.indices = np.random.choice(self._indices, self.mini_epoch_len, replace=True)
+                self.indices = np.random.choice(
+                    self._indices, self.mini_epoch_len, replace=True
+                )
 
     def __iter__(self) -> Iterator[int]:
         """Iterate over sampler.
@@ -601,85 +496,6 @@ class MiniEpochSampler(Sampler):
         return self.mini_epoch_len
 
 
-class DynamicLenBatchSampler(BatchSampler):
-    """
-    A dynamic batch length data sampler.
-    Should be used with `catalyst.utils.trim_tensors`.
-
-    Adapted from `Dynamic minibatch trimming to improve BERT training speed`_.
-
-    Args:
-        sampler: Base sampler.
-        batch_size: Size of minibatch.
-        drop_last: If ``True``, the sampler will drop the last batch
-        if its size would be less than ``batch_size``.
-
-    Usage example:
-
-        >>> from torch.utils import data
-        >>> from catalyst.data import DynamicLenBatchSampler
-        >>> from catalyst import utils
-
-        >>> dataset = data.TensorDataset(
-        >>>     input_ids, input_mask, segment_ids, labels
-        >>> )
-
-        >>> sampler_ = data.RandomSampler(dataset)
-        >>> sampler = DynamicLenBatchSampler(
-        >>>     sampler_, batch_size=16, drop_last=False
-        >>> )
-        >>> loader = data.DataLoader(dataset, batch_sampler=sampler)
-
-        >>> for batch in loader:
-        >>>     tensors = utils.trim_tensors(batch)
-        >>>     b_input_ids, b_input_mask, b_segment_ids, b_labels = \
-        >>>         tuple(t.to(device) for t in tensors)
-
-    .. _`Dynamic minibatch trimming to improve BERT training speed`:
-        https://www.kaggle.com/c/jigsaw-unintended-bias-in-toxicity-classification/discussion/94779
-    """
-
-    def __iter__(self):
-        """
-        Iteration over BatchSampler.
-        """
-        buckets = [[]] * 100
-        yielded = 0
-
-        for idx in self.sampler:
-            count_zeros = torch.sum(self.sampler.data_source[idx][0] == 0)
-            count_zeros = int(count_zeros / 64)
-            if len(buckets[count_zeros]) == 0:
-                buckets[count_zeros] = []
-
-            buckets[count_zeros].append(idx)
-
-            if len(buckets[count_zeros]) == self.batch_size:
-                batch = list(buckets[count_zeros])
-                yield batch
-                yielded += 1
-                buckets[count_zeros] = []
-
-        batch = []
-        leftover = [idx2 for bucket in buckets for idx2 in bucket]
-
-        for idx3 in leftover:
-            batch.append(idx3)
-            if len(batch) == self.batch_size:
-                yielded += 1
-                yield batch
-                batch = []
-
-        if len(batch) > 0 and not self.drop_last:
-            yielded += 1
-            yield batch
-
-        assert len(self) == yielded, (
-            "produced an inccorect number of batches. "
-            + "expected %i, but yielded %i" % (len(self), yielded)
-        )
-
-
 class DistributedSamplerWrapper(DistributedSampler):
     """
     Wrapper over `Sampler` for distributed training.
@@ -707,14 +523,17 @@ class DistributedSamplerWrapper(DistributedSampler):
         Args:
             sampler: Sampler used for subsampling
             num_replicas (int, optional): Number of processes participating in
-              distributed training
+                distributed training
             rank (int, optional): Rank of the current process
-              within ``num_replicas``
+                within ``num_replicas``
             shuffle (bool, optional): If true (default),
-              sampler will shuffle the indices
+                sampler will shuffle the indices
         """
         super(DistributedSamplerWrapper, self).__init__(
-            DatasetFromSampler(sampler), num_replicas=num_replicas, rank=rank, shuffle=shuffle,
+            DatasetFromSampler(sampler),
+            num_replicas=num_replicas,
+            rank=rank,
+            shuffle=shuffle,
         )
         self.sampler = sampler
 
@@ -732,10 +551,8 @@ class DistributedSamplerWrapper(DistributedSampler):
 
 __all__ = [
     "BalanceClassSampler",
-    "BalanceBatchSampler",
     "BatchBalanceClassSampler",
     "DistributedSamplerWrapper",
     "DynamicBalanceClassSampler",
-    "DynamicLenBatchSampler",
     "MiniEpochSampler",
 ]
