@@ -1,22 +1,24 @@
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, Iterable, Optional, Union
 
 import numpy as np
+
 import torch
 
-from catalyst.metrics._additive import AdditiveValueMetric
+from catalyst.metrics._additive import AdditiveMetric
 from catalyst.metrics._metric import ICallbackBatchMetric
+from catalyst.metrics._topk_metric import TopKMetric
 from catalyst.metrics.functional._accuracy import accuracy, multilabel_accuracy
-from catalyst.metrics.functional._misc import get_default_topk_args
+from catalyst.metrics.functional._misc import get_default_topk
 
 
-class AccuracyMetric(ICallbackBatchMetric):
+class AccuracyMetric(TopKMetric):
     """
     This metric computes accuracy for multiclass classification case.
     It computes mean value of accuracy and it's approximate std value
     (note that it's not a real accuracy std but std of accuracy over batch mean values).
 
     Args:
-        topk_args: list of `topk` for accuracy@topk computing
+        topk: list of `topk` for accuracy@topk computing
         num_classes: number of classes
         compute_on_call: if True, computes and returns metric value during metric call
         prefix: metric prefix
@@ -36,7 +38,7 @@ class AccuracyMetric(ICallbackBatchMetric):
             [0.0, 0.8, 0.2, 0.0],
         ])
         targets = torch.tensor([3, 0, 2, 2])
-        metric = metrics.AccuracyMetric(topk_args=(1, 3))
+        metric = metrics.AccuracyMetric(topk=(1, 3))
 
         metric.reset()
         metric.update(outputs, targets)
@@ -48,8 +50,6 @@ class AccuracyMetric(ICallbackBatchMetric):
 
         metric.compute_key_value()
         # {
-        #     'accuracy': 0.5,
-        #     'accuracy/std': 0.0,
         #     'accuracy01': 0.5,
         #     'accuracy01/std': 0.0,
         #     'accuracy03': 1.0,
@@ -87,7 +87,10 @@ class AccuracyMetric(ICallbackBatchMetric):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss"
         )
         runner.train(
             model=model,
@@ -112,103 +115,45 @@ class AccuracyMetric(ICallbackBatchMetric):
             ],
         )
 
+    .. note::
+        Metric names depending on input parameters:
+
+        - ``topk = None`` ---> see \
+            :py:mod:`catalyst.metrics.functional._misc.get_default_topk`
+        - ``topk = (1,)`` ---> ``"accuracy01"``
+        - ``topk = (1, 3)`` ---> ``"accuracy01"``, ``"accuracy03"``
+        - ``topk = (1, 3, 5)`` ---> ``"accuracy01"``, ``"accuracy03"``, ``"accuracy05"``
+
+        You can find them in ``runner.batch_metrics``, ``runner.loader_metrics`` or
+        ``runner.epoch_metrics``.
+
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
         self,
-        topk_args: List[int] = None,
+        topk: Iterable[int] = None,
         num_classes: int = None,
         compute_on_call: bool = True,
         prefix: str = None,
         suffix: str = None,
     ):
         """Init AccuracyMetric"""
-        super().__init__(compute_on_call=compute_on_call, prefix=prefix, suffix=suffix)
-        self.metric_name_mean = f"{self.prefix}accuracy{self.suffix}"
-        self.metric_name_std = f"{self.prefix}accuracy{self.suffix}/std"
-        self.topk_args: List[int] = topk_args or get_default_topk_args(num_classes)
-        self.additive_metrics: List[AdditiveValueMetric] = [
-            AdditiveValueMetric() for _ in range(len(self.topk_args))
-        ]
-
-    def reset(self) -> None:
-        """Reset all fields"""
-        for metric in self.additive_metrics:
-            metric.reset()
-
-    def update(self, logits: torch.Tensor, targets: torch.Tensor) -> List[float]:
-        """
-        Updates metric value with accuracy for new data and return intermediate metrics values.
-
-        Args:
-            logits: tensor of logits
-            targets: tensor of targets
-
-        Returns:
-            list of accuracy@k values
-        """
-        values = accuracy(logits, targets, topk=self.topk_args)
-        values = [v.item() for v in values]
-        for value, metric in zip(values, self.additive_metrics):
-            metric.update(value, len(targets))
-        return values
-
-    def update_key_value(self, logits: torch.Tensor, targets: torch.Tensor) -> Dict[str, float]:
-        """
-        Update metric value with accuracy for new data and return intermediate metrics
-        values in key-value format.
-
-        Args:
-            logits: tensor of logits
-            targets: tensor of targets
-
-        Returns:
-            dict of accuracy@k values
-        """
-        values = self.update(logits=logits, targets=targets)
-        output = {
-            f"{self.prefix}accuracy{key:02d}{self.suffix}": value
-            for key, value in zip(self.topk_args, values)
-        }
-        output[self.metric_name_mean] = output[f"{self.prefix}accuracy01{self.suffix}"]
-        return output
-
-    def compute(self) -> Tuple[List[float], List[float]]:
-        """
-        Compute accuracy for all data
-
-        Returns:
-            list of mean values, list of std values
-        """
-        means, stds = zip(*(metric.compute() for metric in self.additive_metrics))
-        return means, stds
-
-    def compute_key_value(self) -> Dict[str, float]:
-        """
-        Compute accuracy for all data and return results in key-value format
-
-        Returns:
-            dict of metrics
-        """
-        means, stds = self.compute()
-        output_mean = {
-            f"{self.prefix}accuracy{key:02d}{self.suffix}": value
-            for key, value in zip(self.topk_args, means)
-        }
-        output_std = {
-            f"{self.prefix}accuracy{key:02d}{self.suffix}/std": value
-            for key, value in zip(self.topk_args, stds)
-        }
-        output_mean[self.metric_name_mean] = output_mean[f"{self.prefix}accuracy01{self.suffix}"]
-        output_std[self.metric_name_std] = output_std[f"{self.prefix}accuracy01{self.suffix}/std"]
-        return {**output_mean, **output_std}
+        self.topk = topk or get_default_topk(num_classes)
+        super().__init__(
+            metric_name="accuracy",
+            metric_function=accuracy,
+            topk=self.topk,
+            compute_on_call=compute_on_call,
+            prefix=prefix,
+            suffix=suffix,
+        )
 
 
-class MultilabelAccuracyMetric(AdditiveValueMetric, ICallbackBatchMetric):
+class MultilabelAccuracyMetric(AdditiveMetric, ICallbackBatchMetric):
     """
     This metric computes accuracy for multilabel classification case.
     It computes mean value of accuracy and it's approximate std value
@@ -280,7 +225,10 @@ class MultilabelAccuracyMetric(AdditiveValueMetric, ICallbackBatchMetric):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss"
         )
         runner.train(
             model=model,
@@ -305,7 +253,7 @@ class MultilabelAccuracyMetric(AdditiveValueMetric, ICallbackBatchMetric):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -325,7 +273,8 @@ class MultilabelAccuracyMetric(AdditiveValueMetric, ICallbackBatchMetric):
 
     def update(self, outputs: torch.Tensor, targets: torch.Tensor) -> float:
         """
-        Update metric value with accuracy for new data and return intermediate metric value.
+        Update metric value with accuracy for new data
+        and return intermediate metric value.
 
         Args:
             outputs: tensor of outputs
@@ -340,7 +289,9 @@ class MultilabelAccuracyMetric(AdditiveValueMetric, ICallbackBatchMetric):
         super().update(value=metric, num_samples=np.prod(targets.shape))
         return metric
 
-    def update_key_value(self, outputs: torch.Tensor, targets: torch.Tensor) -> Dict[str, float]:
+    def update_key_value(
+        self, outputs: torch.Tensor, targets: torch.Tensor
+    ) -> Dict[str, float]:
         """
         Update metric value with accuracy for new data and return intermediate metric
         value in key-value format.
