@@ -2,16 +2,18 @@ from typing import Any, Callable, Tuple, Union
 import functools
 
 import numpy as np
+
 import torch
 
 from catalyst.metrics._metric import IMetric
-from catalyst.utils.torch import detach_tensor
 
 
 def _to_numpy_wrapper(metric_fn: Callable) -> Callable:
     @functools.wraps(metric_fn)
-    def _wrapper(value: torch.Tensor, *args: Any, **kwargs: Any) -> Union[float, np.ndarray]:
-        np_tensor = detach_tensor(value)
+    def _wrapper(
+        value: torch.Tensor, *args: Any, **kwargs: Any
+    ) -> Union[float, np.ndarray]:
+        np_tensor = value.cpu().detach().numpy()
         value = metric_fn(np_tensor, *args, **kwargs)
 
         return value
@@ -19,7 +21,7 @@ def _to_numpy_wrapper(metric_fn: Callable) -> Callable:
     return _wrapper
 
 
-class AdditiveValueMetric(IMetric):
+class AdditiveMetric(IMetric):
     """This metric computes mean and std values of input data.
 
     Args:
@@ -40,7 +42,7 @@ class AdditiveValueMetric(IMetric):
         num_samples_list = [1, 2, 3, 4, 5]
         true_values = [1, 1.666667, 2.333333, 3, 3.666667]
 
-        metric = metrics.AdditiveValueMetric()
+        metric = metrics.AdditiveMetric()
         for value, num_samples, true_value in zip(values, num_samples_list, true_values):
             metric.update(value=value, num_samples=num_samples)
             mean, _ = metric.compute()
@@ -65,7 +67,7 @@ class AdditiveValueMetric(IMetric):
                 batch_size=32
             ),
             "valid": DataLoader(
-                MNIST(os.getcwd(), train=False, download=True, transform=ToTensor()),
+                MNIST(os.getcwd(), train=False),
                 batch_size=32
             ),
         }
@@ -78,7 +80,7 @@ class AdditiveValueMetric(IMetric):
             def on_loader_start(self, runner):
                 super().on_loader_start(runner)
                 self.meters = {
-                    key: metrics.AdditiveValueMetric(compute_on_call=False)
+                    key: metrics.AdditiveMetric(compute_on_call=False)
                     for key in ["loss", "accuracy01", "accuracy03"]
                 }
 
@@ -97,10 +99,12 @@ class AdditiveValueMetric(IMetric):
                     {"loss": loss, "accuracy01": accuracy01, "accuracy03": accuracy03}
                 )
                 for key in ["loss", "accuracy01", "accuracy03"]:
-                    self.meters[key].update(self.batch_metrics[key].item(), self.batch_size)
+                    self.meters[key].update(
+                        self.batch_metrics[key].item(), self.batch_size
+                    )
                 # run model backward pass
                 if self.is_train_loader:
-                    loss.backward()
+                    self.engine.backward(loss)
                     self.optimizer.step()
                     self.optimizer.zero_grad()
 
@@ -126,11 +130,11 @@ class AdditiveValueMetric(IMetric):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(self, compute_on_call: bool = True, mode: str = "numpy"):
-        """Init AdditiveValueMetric"""
+        """Init AdditiveMetric"""
         super().__init__(compute_on_call=compute_on_call)
         self.n = 0
         self.value = 0.0
@@ -172,7 +176,7 @@ class AdditiveValueMetric(IMetric):
 
         if self.n == 1:
             # Force a copy in torch/numpy
-            self.mean = 0.0 + value  # noqa: WPS345
+            self.mean = 0.0 + value
             self.std = 0.0
             self.mean_old = self.mean
             self.m_s = 0.0
@@ -195,4 +199,6 @@ class AdditiveValueMetric(IMetric):
         return self.mean, self.std
 
 
-__all__ = ["AdditiveValueMetric"]
+AdditiveValueMetric = AdditiveMetric
+
+__all__ = ["AdditiveMetric", "AdditiveValueMetric"]
