@@ -5,7 +5,14 @@ import torch
 from catalyst.metrics._metric import ICallbackLoaderMetric
 from catalyst.metrics.functional._auc import auc, binary_auc
 from catalyst.metrics.functional._misc import process_multilabel_components
-from catalyst.utils.distributed import all_gather, get_rank
+from catalyst.settings import SETTINGS
+from catalyst.utils import get_device
+from catalyst.utils.distributed import all_gather, get_backend
+
+# @TODO: remove `all_gather` and `get_backend` dependencies from metrics
+
+if SETTINGS.xla_required:
+    import torch_xla.core.xla_model as xm
 
 
 class AUCMetric(ICallbackLoaderMetric):
@@ -13,6 +20,8 @@ class AUCMetric(ICallbackLoaderMetric):
 
     Args:
         compute_on_call: if True, computes and returns metric value during metric call
+        compute_per_class_metrics: boolean flag to compute per-class metrics
+            (default: SETTINGS.compute_per_class_metrics or False).
         prefix: metric prefix
         suffix: metric suffix
 
@@ -91,7 +100,10 @@ class AUCMetric(ICallbackLoaderMetric):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss",
         )
         runner.train(
             model=model,
@@ -119,20 +131,28 @@ class AUCMetric(ICallbackLoaderMetric):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
-    def __init__(self, compute_on_call: bool = True, prefix: str = None, suffix: str = None):
+    def __init__(
+        self,
+        compute_on_call: bool = True,
+        compute_per_class_metrics: bool = SETTINGS.compute_per_class_metrics,
+        prefix: str = None,
+        suffix: str = None,
+    ):
         """Init."""
         super().__init__(compute_on_call=compute_on_call, prefix=prefix, suffix=suffix)
         self.metric_name = f"{self.prefix}auc{self.suffix}"
+        self._ddp_backend = None
+        self.compute_per_class_metrics = compute_per_class_metrics
         self.scores = []
         self.targets = []
-        self._is_ddp = get_rank() > -1
+        self.reset(0, 0)
 
     def reset(self, num_batches, num_samples) -> None:
         """Resets all fields"""
-        self._is_ddp = get_rank() > -1
+        self._ddp_backend = get_backend()
         self.scores = []
         self.targets = []
 
@@ -151,21 +171,33 @@ class AUCMetric(ICallbackLoaderMetric):
         targets = torch.cat(self.targets)
         scores = torch.cat(self.scores)
 
-        # @TODO: ddp hotfix, could be done better
-        if self._is_ddp:
+        # ddp hotfix, could be done better
+        # but metric must handle DDP on it's own
+        if self._ddp_backend == "xla":
+            # if you have "RuntimeError: Aborted: Session XXX is not found" here
+            # please, ask Google for a more powerful TPU setup ;)
+            device = get_device()
+            scores = xm.all_gather(scores.to(device)).cpu().detach()
+            targets = xm.all_gather(targets.to(device)).cpu().detach()
+        elif self._ddp_backend == "ddp":
             scores = torch.cat(all_gather(scores))
             targets = torch.cat(all_gather(targets))
 
-        scores, targets, _ = process_multilabel_components(outputs=scores, targets=targets)
+        scores, targets, _, _ = process_multilabel_components(
+            outputs=scores, targets=targets
+        )
         per_class = auc(scores=scores, targets=targets)
         micro = binary_auc(scores=scores.view(-1), targets=targets.view(-1))[0]
         macro = per_class.mean().item()
         weights = targets.sum(axis=0) / len(targets)
         weighted = (per_class * weights).sum().item()
-        return per_class, micro, macro, weighted
+        if self.compute_per_class_metrics:
+            return per_class, micro, macro, weighted
+        else:
+            return [], micro, macro, weighted
 
     def compute_key_value(self) -> Dict[str, float]:
-        """Computes the AUC metric based on saved statistics and returns key-value results."""
+        """Computes the AUC metric and returns key-value results."""
         per_class_auc, micro_auc, macro_auc, weighted_auc = self.compute()
         output = {
             f"{self.metric_name}/class_{i:02d}": value.item()
