@@ -2,19 +2,19 @@ from typing import Dict, Iterable, List, Optional
 
 import torch
 
-from catalyst.metrics._metric import AccumulationMetric
+from catalyst.metrics._accumulative import AccumulativeMetric
 from catalyst.metrics.functional._cmc_score import cmc_score, masked_cmc_score
 from catalyst.utils.distributed import get_rank
 
 
-class CMCMetric(AccumulationMetric):
+class CMCMetric(AccumulativeMetric):
     """Cumulative Matching Characteristics
 
     Args:
         embeddings_key: key of embedding tensor in batch
         labels_key: key of label tensor in batch
         is_query_key: key of query flag tensor in batch
-        topk_args: list of k, specifies which cmc@k should be calculated
+        topk: list of k, specifies which cmc@k should be calculated
         compute_on_call: if True, allows compute metric's value on call
         prefix: metric prefix
         suffix: metric suffix
@@ -47,7 +47,7 @@ class CMCMetric(AccumulationMetric):
             embeddings_key="embeddings",
             labels_key="labels",
             is_query_key="is_query",
-            topk_args=topk,
+            topk=topk,
         )
         metric.reset(num_batches=1, num_samples=len(batch["embeddings"]))
 
@@ -64,20 +64,21 @@ class CMCMetric(AccumulationMetric):
         from torch.optim import Adam
         from torch.utils.data import DataLoader
         from catalyst import data, dl
-        from catalyst.contrib import datasets, models, nn
-        from catalyst.data.transforms import Compose, Normalize, ToTensor
+        from catalyst.contrib import data.datasets, models, nn
 
 
         # 1. train and valid loaders
-        transforms = Compose([ToTensor(), Normalize((0.1307,), (0.3081,))])
+        transforms = data.Compose([
+            data.ImageToTensor(), data.NormalizeImage((0.1307,), (0.3081,))
+        ])
 
         train_dataset = datasets.MnistMLDataset(
             root=os.getcwd(), download=True, transform=transforms
         )
-        sampler = data.BalanceBatchSampler(labels=train_dataset.get_labels(), p=5, k=10)
-        train_loader = DataLoader(
-            dataset=train_dataset, sampler=sampler, batch_size=sampler.batch_size
+        sampler = data.BatchBalanceClassSampler(
+            labels=train_dataset.get_labels(), num_classes=5, num_samples=10
         )
+        train_loader = DataLoader(dataset=train_dataset, batch_sampler=sampler)
 
         valid_dataset = datasets.MnistQGDataset(
             root=os.getcwd(), transform=transforms, gallery_fraq=0.2
@@ -90,7 +91,9 @@ class CMCMetric(AccumulationMetric):
 
         # 3. criterion with triplets sampling
         sampler_inbatch = data.HardTripletsSampler(norm_required=False)
-        criterion = nn.TripletMarginLossWithSampler(margin=0.5, sampler_inbatch=sampler_inbatch)
+        criterion = nn.TripletMarginLossWithSampler(
+            margin=0.5, sampler_inbatch=sampler_inbatch
+        )
 
         # 4. training with catalyst Runner
         class CustomRunner(dl.SupervisedRunner):
@@ -98,7 +101,7 @@ class CMCMetric(AccumulationMetric):
                 if self.is_train_loader:
                     images, targets = batch["features"].float(), batch["targets"].long()
                     features = self.model(images)
-                    self.batch = {"embeddings": features, "targets": targets,}
+                    self.batch = {"embeddings": features, "targets": targets}
                 else:
                     images, targets, is_query = (
                         batch["features"].float(),
@@ -122,12 +125,15 @@ class CMCMetric(AccumulationMetric):
                     embeddings_key="embeddings",
                     labels_key="targets",
                     is_query_key="is_query",
-                    topk_args=[1],
+                    topk=[1],
                 ),
                 loaders="valid",
             ),
             dl.PeriodicLoaderCallback(
-                valid_loader_key="valid", valid_metric_key="cmc01", minimize=False, valid=2
+                valid_loader_key="valid",
+                valid_metric_key="cmc01",
+                minimize=False,
+                valid=2
             ),
         ]
 
@@ -146,10 +152,20 @@ class CMCMetric(AccumulationMetric):
             num_epochs=10,
         )
 
+    .. note::
+        Metric names depending on input parameters:
+
+        - ``topk = (1,) or None`` ---> ``"cmc01"``
+        - ``topk = (1, 3)`` ---> ``"cmc01"``, ``"cmc03"``
+        - ``topk = (1, 3, 5)`` ---> ``"cmc01"``, ``"cmc03"``, ``"cmc05"``
+
+        You can find them in ``runner.batch_metrics``, ``runner.loader_metrics`` or
+        ``runner.epoch_metrics``.
+
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
     def __init__(
@@ -157,7 +173,7 @@ class CMCMetric(AccumulationMetric):
         embeddings_key: str,
         labels_key: str,
         is_query_key: str,
-        topk_args: Iterable[int] = None,
+        topk: Iterable[int] = None,
         compute_on_call: bool = True,
         prefix: Optional[str] = None,
         suffix: Optional[str] = None,
@@ -167,13 +183,12 @@ class CMCMetric(AccumulationMetric):
             compute_on_call=compute_on_call,
             prefix=prefix,
             suffix=suffix,
-            accumulative_fields=[embeddings_key, labels_key, is_query_key],
+            keys=[embeddings_key, labels_key, is_query_key],
         )
         self.embeddings_key = embeddings_key
         self.labels_key = labels_key
         self.is_query_key = is_query_key
-        self.topk_args = topk_args or (1,)
-        self.metric_name = f"{self.prefix}cmc{self.suffix}"
+        self.topk = topk or (1,)
 
     def reset(self, num_batches: int, num_samples: int) -> None:
         """
@@ -204,10 +219,12 @@ class CMCMetric(AccumulationMetric):
         gallery_embeddings = embeddings[~query_mask]
         gallery_labels = labels[~query_mask]
 
-        conformity_matrix = (gallery_labels == query_labels.reshape(-1, 1)).to(torch.bool)
+        conformity_matrix = (gallery_labels == query_labels.reshape(-1, 1)).to(
+            torch.bool
+        )
 
         metrics = []
-        for k in self.topk_args:
+        for k in self.topk:
             value = cmc_score(
                 query_embeddings=query_embeddings,
                 gallery_embeddings=gallery_embeddings,
@@ -227,12 +244,13 @@ class CMCMetric(AccumulationMetric):
         """
         values = self.compute()
         kv_metrics = {
-            f"{self.metric_name}{k:02d}": value for k, value in zip(self.topk_args, values)
+            f"{self.prefix}cmc{k:02d}{self.suffix}": value
+            for k, value in zip(self.topk, values)
         }
         return kv_metrics
 
 
-class ReidCMCMetric(AccumulationMetric):
+class ReidCMCMetric(AccumulativeMetric):
     """Cumulative Matching Characteristics for Reid case
 
     Args:
@@ -240,7 +258,7 @@ class ReidCMCMetric(AccumulationMetric):
         pids_key: key of pids tensor in batch
         cids_key: key of cids tensor in batch
         is_query_key: key of query flag tensor in batch
-        topk_args: list of k, specifies which cmc@k should be calculated
+        topk: list of k, specifies which cmc@k should be calculated
         compute_on_call: if True, allows compute metric's value on call
         prefix: metric prefix
         suffix: metric suffix
@@ -275,7 +293,7 @@ class ReidCMCMetric(AccumulationMetric):
             pids_key="pids",
             cids_key="cids",
             is_query_key="is_query",
-            topk_args=topk,
+            topk=topk,
         )
         metric.reset(num_batches=1, num_samples=len(batch["embeddings"]))
 
@@ -293,7 +311,7 @@ class ReidCMCMetric(AccumulationMetric):
         pids_key: str,
         cids_key: str,
         is_query_key: str,
-        topk_args: Iterable[int] = None,
+        topk: Iterable[int] = None,
         compute_on_call: bool = True,
         prefix: Optional[str] = None,
         suffix: Optional[str] = None,
@@ -303,14 +321,13 @@ class ReidCMCMetric(AccumulationMetric):
             compute_on_call=compute_on_call,
             prefix=prefix,
             suffix=suffix,
-            accumulative_fields=[embeddings_key, pids_key, cids_key, is_query_key],
+            keys=[embeddings_key, pids_key, cids_key, is_query_key],
         )
         self.embeddings_key = embeddings_key
         self.pids_key = pids_key
         self.cids_key = cids_key
         self.is_query_key = is_query_key
-        self.topk_args = topk_args or (1,)
-        self.metric_name = f"{self.prefix}cmc{self.suffix}"
+        self.topk = topk or (1,)
 
     def reset(self, num_batches: int, num_samples: int) -> None:
         """
@@ -331,7 +348,8 @@ class ReidCMCMetric(AccumulationMetric):
             list of metrics values
 
         Raises:
-            ValueError: if there are samples in query that have no relevant samples in gallery
+            ValueError: if there are samples in query
+            that have no relevant samples in gallery
         """
         query_mask = (self.storage[self.is_query_key] == 1).to(torch.bool)
 
@@ -360,10 +378,12 @@ class ReidCMCMetric(AccumulationMetric):
         available_samples = ~(pid_conformity_matrix * cid_conformity_matrix).bool()
 
         if (available_samples.max(dim=1).values == 0).any():
-            raise ValueError("There is a sample in query that has no relevant samples in gallery.")
+            raise ValueError(
+                "There is a sample in query that has no relevant samples in gallery."
+            )
 
         metrics = []
-        for k in self.topk_args:
+        for k in self.topk:
             value = masked_cmc_score(
                 query_embeddings=query_embeddings,
                 gallery_embeddings=gallery_embeddings,
@@ -384,7 +404,8 @@ class ReidCMCMetric(AccumulationMetric):
         """
         values = self.compute()
         kv_metrics = {
-            f"{self.metric_name}{k:02d}": value for k, value in zip(self.topk_args, values)
+            f"{self.prefix}cmc{k:02d}{self.suffix}": value
+            for k, value in zip(self.topk, values)
         }
         return kv_metrics
 
