@@ -1,10 +1,16 @@
 from typing import Any, List
 
 import numpy as np
+
 import torch
 
 from catalyst.metrics._metric import IMetric
-from catalyst.utils.distributed import all_gather, get_rank
+from catalyst.settings import SETTINGS
+from catalyst.utils import get_device
+from catalyst.utils.distributed import all_gather, get_backend
+
+if SETTINGS.xla_required:
+    import torch_xla.core.xla_model as xm
 
 
 class ConfusionMatrixMetric(IMetric):
@@ -12,8 +18,9 @@ class ConfusionMatrixMetric(IMetric):
 
     Args:
         num_classes: number of classes in the classification problem
-        normalized: determines whether or not the confusion matrix is normalized or not
-        compute_on_call: Boolean flag to computes and return confusion matrix during __call__.
+        normalize: determines whether or not the confusion matrix is normalize or not
+        compute_on_call: Boolean flag to computes
+            and return confusion matrix during __call__.
             default: True
 
     Examples:
@@ -42,7 +49,10 @@ class ConfusionMatrixMetric(IMetric):
 
         # model training
         runner = dl.SupervisedRunner(
-            input_key="features", output_key="logits", target_key="targets", loss_key="loss"
+            input_key="features",
+            output_key="logits",
+            target_key="targets",
+            loss_key="loss"
         )
         runner.train(
             model=model,
@@ -73,22 +83,24 @@ class ConfusionMatrixMetric(IMetric):
     .. note::
         Please follow the `minimal examples`_ sections for more use cases.
 
-        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples  # noqa: E501, W505
     """
 
-    def __init__(self, num_classes: int, normalized: bool = False, compute_on_call: bool = True):
+    def __init__(
+        self, num_classes: int, normalize: bool = False, compute_on_call: bool = True
+    ):
         """Constructs a confusion matrix for a multiclass classification problems."""
         super().__init__(compute_on_call=compute_on_call)
         self.num_classes = num_classes
-        self.normalized = normalized
+        self.normalize = normalize
         self.conf = np.ndarray((num_classes, num_classes), dtype=np.int32)
-        self._is_ddp = False
+        self._ddp_backend = None
         self.reset()
 
     def reset(self) -> None:
         """Reset confusion matrix, filling it with zeros."""
         self.conf.fill(0)
-        self._is_ddp = get_rank() > -1
+        self._ddp_backend = get_backend()
 
     def update(self, predictions: torch.Tensor, targets: torch.Tensor) -> None:
         """Computes the confusion matrix of ``K x K`` size where ``K`` is no of classes.
@@ -135,9 +147,7 @@ class ConfusionMatrixMetric(IMetric):
 
         # hack for bincounting 2 arrays together
         x = predictions + self.num_classes * targets
-        bincount_2d = np.bincount(
-            x.astype(np.int32), minlength=self.num_classes ** 2
-        )  # noqa: WPS114
+        bincount_2d = np.bincount(x.astype(np.int32), minlength=self.num_classes ** 2)
         assert bincount_2d.size == self.num_classes ** 2
         conf = bincount_2d.reshape((self.num_classes, self.num_classes))
 
@@ -150,11 +160,20 @@ class ConfusionMatrixMetric(IMetric):
             to ground-truth targets and columns corresponds to predicted
             targets.
         """
-        if self._is_ddp:
+        # ddp hotfix, could be done better
+        # but metric must handle DDP on it's own
+        if self._ddp_backend == "xla":
+            # if you have "RuntimeError: Aborted: Session XXX is not found" here
+            # please, ask Google for a more powerful TPU setup ;)
+            device = get_device()
+            value = torch.tensor([self.conf], device=device)
+            self.conf = xm.all_gather(value).sum(0).cpu().detach().numpy()
+        elif self._ddp_backend == "ddp":
             value: List[np.ndarray] = all_gather(self.conf)
             value: np.ndarray = np.sum(np.stack(value, axis=0), axis=0)
             self.conf = value
-        if self.normalized:
+
+        if self.normalize:
             conf = self.conf.astype(np.float32)
             return conf / conf.sum(1).clip(min=1e-12)[:, None]
         else:
