@@ -1,13 +1,14 @@
 from typing import Sequence, Union
 
 import numpy as np
+
 import torch
 
 from catalyst.metrics.functional import process_multilabel_components
 
 
 def accuracy(
-    outputs: torch.Tensor, targets: torch.Tensor, topk: Sequence[int] = (1,),
+    outputs: torch.Tensor, targets: torch.Tensor, topk: Sequence[int] = (1,)
 ) -> Sequence[torch.Tensor]:
     """
     Computes multiclass accuracy@topk for the specified values of `topk`.
@@ -90,7 +91,7 @@ def accuracy(
         pred = outputs.t()
     else:
         # multiclass accuracy
-        _, pred = outputs.topk(max_k, 1, True, True)  # noqa: WPS425
+        _, pred = outputs.topk(max_k, 1, True, True)
         pred = pred.t()
     correct = pred.eq(targets.long().view(1, -1).expand_as(pred))
 
@@ -102,7 +103,7 @@ def accuracy(
 
 
 def multilabel_accuracy(
-    outputs: torch.Tensor, targets: torch.Tensor, threshold: Union[float, torch.Tensor],
+    outputs: torch.Tensor, targets: torch.Tensor, threshold: Union[float, torch.Tensor]
 ) -> torch.Tensor:
     """
     Computes multilabel accuracy for the specified activation and threshold.
@@ -173,7 +174,9 @@ def multilabel_accuracy(
         )
         # tensor(1.0)
     """
-    outputs, targets, _ = process_multilabel_components(outputs=outputs, targets=targets)
+    outputs, targets, _, _ = process_multilabel_components(
+        outputs=outputs, targets=targets
+    )
 
     outputs = (outputs > threshold).long()
     output = (targets.long() == outputs.long()).sum().float() / np.prod(targets.shape)
