@@ -9,7 +9,7 @@ from catalyst.metrics.functional._misc import (
 
 
 def binary_average_precision(
-    outputs: torch.Tensor, targets: torch.Tensor, weights: Optional[torch.Tensor] = None,
+    outputs: torch.Tensor, targets: torch.Tensor, weights: Optional[torch.Tensor] = None
 ) -> torch.Tensor:
     """Computes the binary average precision.
 
@@ -40,8 +40,8 @@ def binary_average_precision(
     """
     # outputs - [bs; num_classes] with scores
     # targets - [bs; num_classes] with binary labels
-    outputs, targets, weights = process_multilabel_components(
-        outputs=outputs, targets=targets, weights=weights,
+    outputs, targets, weights, _ = process_multilabel_components(
+        outputs=outputs, targets=targets, weights=weights
     )
     if outputs.numel() == 0:
         return torch.zeros(1)
@@ -76,7 +76,9 @@ def binary_average_precision(
     return ap
 
 
-def average_precision(outputs: torch.Tensor, targets: torch.Tensor, k: int) -> torch.Tensor:
+def average_precision(
+    outputs: torch.Tensor, targets: torch.Tensor, k: int
+) -> torch.Tensor:
     """
     Calculate the Average Precision for RecSys.
     The precision metric summarizes the fraction of relevant items
@@ -139,16 +141,18 @@ def average_precision(outputs: torch.Tensor, targets: torch.Tensor, k: int) -> t
     precisions = torch.zeros_like(targets_sort_by_outputs)
 
     for index in range(k):
-        precisions[:, index] = torch.sum(targets_sort_by_outputs[:, : (index + 1)], dim=1) / float(
-            index + 1
-        )
+        precisions[:, index] = torch.sum(
+            targets_sort_by_outputs[:, : (index + 1)], dim=1
+        ) / float(index + 1)
 
-        precisions[:, index] = torch.sum(targets_sort_by_outputs[:, : (index + 1)], dim=1) / float(
-            index + 1
-        )
+        precisions[:, index] = torch.sum(
+            targets_sort_by_outputs[:, : (index + 1)], dim=1
+        ) / float(index + 1)
 
     only_relevant_precision = precisions * targets_sort_by_outputs
-    ap_score = only_relevant_precision.sum(dim=1) / ((only_relevant_precision != 0).sum(dim=1))
+    ap_score = only_relevant_precision.sum(dim=1) / (
+        (only_relevant_precision != 0).sum(dim=1)
+    )
     ap_score[torch.isnan(ap_score)] = 0
     return ap_score
 
