@@ -2,7 +2,7 @@ import torch
 
 
 def cmc_score_count(
-    distances: torch.Tensor, conformity_matrix: torch.Tensor, topk: int = 1,
+    distances: torch.Tensor, conformity_matrix: torch.Tensor, topk: int = 1
 ) -> float:
     """
     Function to count CMC from distance matrix and conformity matrix.
@@ -43,7 +43,9 @@ def cmc_score_count(
     position_matrix = torch.argsort(perm_matrix)
     conformity_matrix = conformity_matrix.type(torch.bool)
 
-    position_matrix[~conformity_matrix] = topk + 1  # value large enough not to be counted
+    position_matrix[~conformity_matrix] = (
+        topk + 1
+    )  # value large enough not to be counted
 
     closest = position_matrix.min(dim=1)[0]
     k_mask = (closest < topk).type(torch.float)
