@@ -3,10 +3,11 @@ import configparser
 import logging
 import os
 
-# from packaging.version import parse, Version
+from packaging.version import Version
+
 import torch
 
-from catalyst.tools.frozen_class import FrozenClass
+from catalyst.extras.frozen_class import FrozenClass
 
 logger = logging.getLogger(__name__)
 
@@ -14,6 +15,10 @@ IS_CUDA_AVAILABLE = torch.cuda.is_available()
 NUM_CUDA_DEVICES = torch.cuda.device_count()
 
 
+def _is_torch_1_7_0():
+    return Version(torch.__version__) >= Version("1.7.0")
+
+
 def _is_apex_avalilable():
     try:
         import apex  # noqa: F401
@@ -33,15 +38,6 @@ def _is_amp_available():
         return False
 
 
-def _is_albumentations_available():
-    try:
-        import albumentations as albu  # noqa: F401
-
-        return True
-    except ModuleNotFoundError:
-        return False
-
-
 def _is_xla_available():
     try:
         import torch_xla.core.xla_model as xm  # noqa: F401
@@ -106,16 +102,6 @@ def _is_optuna_available():
         return False
 
 
-def _is_hydra_available():
-    try:
-        import hydra  # noqa: F401
-        from omegaconf import DictConfig, OmegaConf  # noqa: F401
-
-        return True
-    except ModuleNotFoundError:
-        return False
-
-
 def _is_cv_available():
     try:
         import cv2  # noqa: F401
@@ -128,15 +114,6 @@ def _is_cv_available():
         return False
 
 
-def _is_nifti_available():
-    try:
-        import nibabel  # noqa: F401
-
-        return True
-    except ModuleNotFoundError:
-        return False
-
-
 def _is_ml_available():
     try:
         import matplotlib  # noqa: F401
@@ -167,6 +144,15 @@ def _is_wandb_available():
         return False
 
 
+def _is_comet_available():
+    try:
+        import comet_ml  # noqa: F401
+
+        return True
+    except ImportError:
+        return False
+
+
 def _is_neptune_available():
     try:
         import neptune.new as neptune  # noqa: F401
@@ -176,6 +162,15 @@ def _is_neptune_available():
         return False
 
 
+def _is_yaml_available():
+    try:
+        import yaml  # noqa: F401
+
+        return True
+    except ModuleNotFoundError:
+        return False
+
+
 def _get_optional_value(
     is_required: Optional[bool], is_available_fn: Callable, assert_msg: str
 ) -> bool:
@@ -195,32 +190,27 @@ class Settings(FrozenClass):
         self,
         # [subpackages]
         cv_required: Optional[bool] = None,
-        nifti_required: Optional[bool] = None,
         ml_required: Optional[bool] = None,
         # [integrations]
-        albu_required: Optional[bool] = None,
-        hydra_required: Optional[bool] = None,
-        # nmslib_required: Optional[bool] = False,
         optuna_required: Optional[bool] = None,
-        # [engines]
-        amp_required: Optional[bool] = None,
-        apex_required: Optional[bool] = None,
-        xla_required: Optional[bool] = None,
-        fairscale_required: Optional[bool] = None,
-        deepspeed_required: Optional[bool] = None,
         # [dl-extras]
         onnx_required: Optional[bool] = None,
         pruning_required: Optional[bool] = None,
         quantization_required: Optional[bool] = None,
         # [logging]
-        # alchemy_required: Optional[bool] = None,
-        neptune_required: Optional[bool] = None,
+        comet_required: Optional[bool] = None,
         mlflow_required: Optional[bool] = None,
+        neptune_required: Optional[bool] = None,
         wandb_required: Optional[bool] = None,
         # [extras]
         use_lz4: Optional[bool] = None,
         use_pyarrow: Optional[bool] = None,
         use_libjpeg_turbo: Optional[bool] = None,
+        log_batch_metrics: Optional[bool] = None,
+        log_epoch_metrics: Optional[bool] = None,
+        compute_per_class_metrics: Optional[bool] = None,
+        # [versions]
+        is_torch_1_7_0: Optional[bool] = None,
     ):
         # True – use the package
         # None – use the package if available
@@ -229,63 +219,51 @@ class Settings(FrozenClass):
         self.cv_required: bool = _get_optional_value(
             cv_required,
             _is_cv_available,
-            "catalyst[cv] is not available, to install it, run `pip install catalyst[cv]`.",
+            "catalyst[cv] is not available, "
+            "to install it, run `pip install catalyst[cv]`.",
         )
-        self.nifti_required: bool = _get_optional_value(
-            nifti_required,
-            _is_nifti_available,
-            "catalyst[nifti] is not available, to install it, run `pip install catalyst[nifti]`.",
-        )
-
         self.ml_required: bool = _get_optional_value(
             ml_required,
             _is_ml_available,
-            "catalyst[ml] is not available, to install it, run `pip install catalyst[ml]`.",
+            "catalyst[ml] is not available, "
+            "to install it, run `pip install catalyst[ml]`.",
         )
 
         # [integrations]
-        self.albu_required: bool = _get_optional_value(
-            albu_required,
-            _is_albumentations_available,
-            "catalyst[albu] is not available, to install it, " "run `pip install catalyst[albu]`.",
-        )
-        self.hydra_required: bool = _get_optional_value(
-            hydra_required,
-            _is_hydra_available,
-            "catalyst[hydra] is not available, to install it, run `pip install catalyst[hydra]`.",
-        )
-        # self.nmslib_required: bool = nmslib_required
         self.optuna_required: bool = _get_optional_value(
             optuna_required,
             _is_optuna_available,
-            "catalyst[optuna] is not available, to install it, "
-            "run `pip install catalyst[optuna]`.",
+            "catalyst[optuna] is not available, "
+            "to install it, run `pip install catalyst[optuna]`.",
         )
 
         # [engines]
         self.amp_required: bool = _get_optional_value(
-            amp_required,
+            None,
             _is_amp_available,
-            "catalyst[amp] is not available, to install it, run `pip install catalyst[amp]`.",
+            "catalyst[amp] is not available, "
+            "to install it, run `pip install catalyst[amp]`.",
         )
         self.apex_required: bool = _get_optional_value(
-            apex_required,
+            None,
             _is_apex_avalilable,
-            "catalyst[apex] is not available, to install it, run `pip install catalyst[apex]`.",
+            "catalyst[apex] is not available, "
+            "to install it, run `pip install catalyst[apex]`.",
         )
         self.xla_required: bool = _get_optional_value(
-            xla_required,
+            None,
             _is_xla_available,
-            "catalyst[xla] is not available, to install it, run `pip install catalyst[xla]`.",
+            "catalyst[xla] is not available, "
+            "to install it, run `pip install catalyst[xla]`.",
         )
         self.fairscale_required: bool = _get_optional_value(
-            fairscale_required,
+            None,
             _is_fairscale_available,
             "catalyst[fairscale] is not available, "
             "to install it, run `pip install catalyst[fairscale]`.",
         )
         self.deepspeed_required: bool = _get_optional_value(
-            deepspeed_required,
+            None,
             _is_deepspeed_available,
             "catalyst[deepspeed] is not available, "
             "to install it, run `pip install catalyst[deepspeed]`.",
@@ -313,10 +291,10 @@ class Settings(FrozenClass):
 
         # [logging]
         # self.alchemy_required: bool = alchemy_required
-        self.neptune_required: bool = _get_optional_value(
-            neptune_required,
-            _is_neptune_available,
-            "neptune is not available, to install it, run `pip install neptune-client`.",
+        self.comet_required: bool = _get_optional_value(
+            comet_required,
+            _is_comet_available,
+            "comet is not available, to install, run 'pip install comet_ml'.",
         )
         self.mlflow_required: bool = _get_optional_value(
             mlflow_required,
@@ -324,33 +302,47 @@ class Settings(FrozenClass):
             "catalyst[mlflow] is not available, to install it, "
             "run `pip install catalyst[mlflow]`.",
         )
-
+        self.neptune_required: bool = _get_optional_value(
+            neptune_required,
+            _is_neptune_available,
+            "neptune is not available, to install it, run `pip install neptune-client`.",
+        )
         self.wandb_required: bool = _get_optional_value(
             wandb_required,
             _is_wandb_available,
             "wandb is not available, to install it, " "run `pip install wandb`.",
         )
 
-        # self.wandb_required: bool = wandb_required
-
         # [extras]
-        self.use_lz4: bool = use_lz4 or False
-        self.use_pyarrow: bool = use_pyarrow or False
-        self.use_libjpeg_turbo: bool = use_libjpeg_turbo or False
+        self.yaml_required: bool = _get_optional_value(
+            None,
+            _is_yaml_available,
+            "yaml is not available, to install it, " "run `pip install PyYAML>=5.1`.",
+        )
 
-        # [global]
-        # stages
-        self.stage_train_prefix: str = "train"
-        self.stage_valid_prefix: str = "valid"
-        self.stage_infer_prefix: str = "infer"
+        self.use_lz4: bool = use_lz4 or os.environ.get("CATALYST_USE_LZ4", "0") == "1"
+        self.use_pyarrow: bool = (
+            use_pyarrow or os.environ.get("CATALYST_USE_PYARROW", "0") == "1"
+        )
+        self.use_libjpeg_turbo: bool = (
+            use_libjpeg_turbo or os.environ.get("CATALYST_USE_LIBJPEG_TURBO", "0") == "1"
+        )
 
-        # epoch
-        self.epoch_metrics_prefix: str = "_epoch_"
+        self.log_batch_metrics: bool = (
+            log_batch_metrics or os.environ.get("CATALYST_LOG_BATCH_METRICS", "0") == "1"
+        )
+        self.log_epoch_metrics: bool = (
+            log_epoch_metrics or os.environ.get("CATALYST_LOG_EPOCH_METRICS", "1") == "1"
+        )
+        self.compute_per_class_metrics: bool = (
+            compute_per_class_metrics
+            or os.environ.get("CATALYST_COMPUTE_PER_CLASS_METRICS", "0") == "1"
+        )
 
-        # loader
-        self.loader_train_prefix: str = "train"
-        self.loader_valid_prefix: str = "valid"
-        self.loader_infer_prefix: str = "infer"
+        # [versions]
+        self.is_torch_1_7_0: bool = _get_optional_value(
+            is_torch_1_7_0, _is_torch_1_7_0, "upgrade to torch >= 1.7.0."
+        )
 
     @staticmethod
     def _optional_value(value, default):
@@ -491,7 +483,7 @@ class MergedConfigParser:
 
     #: Set of actions that should use the
     #: :meth:`~configparser.RawConfigParser.getbool` method.
-    GETBOOL_ACTIONS = {"store_true", "store_false"}  # noqa: WPS115
+    GETBOOL_ACTIONS = {"store_true", "store_false"}
 
     def __init__(self, config_finder: ConfigFileFinder):
         """Initialize the MergedConfigParser instance.
@@ -505,7 +497,8 @@ class MergedConfigParser:
     def _normalize_value(self, option, value):
         final_value = option.normalize(value, self.config_finder.local_directory)
         logger.debug(
-            f"{value} has been normalized to {final_value}" f" for option '{option.config_name}'",
+            f"{value} has been normalized to {final_value}"
+            f" for option '{option.config_name}'"
         )
         return final_value
 
@@ -546,7 +539,6 @@ SETTINGS = Settings.parse()
 setattr(SETTINGS, "IS_CUDA_AVAILABLE", IS_CUDA_AVAILABLE)  # noqa: B010
 setattr(SETTINGS, "NUM_CUDA_DEVICES", NUM_CUDA_DEVICES)  # noqa: B010
 
-
 __all__ = [
     "SETTINGS",
     "Settings",
