@@ -1,16 +1,17 @@
-from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Iterable, Optional, Tuple, TypeVar, Union
 import argparse
 from base64 import urlsafe_b64encode
 import collections
 import copy
 from datetime import datetime
 from hashlib import sha256
-import inspect
 from itertools import tee
+import os
 import random
 
 import numpy as np
-from torch import int as tint, long, short, Tensor
+
+import torch
 
 T = TypeVar("T")
 
@@ -19,7 +20,7 @@ def boolean_flag(
     parser: argparse.ArgumentParser,
     name: str,
     default: Optional[bool] = False,
-    help: str = None,  # noqa: WPS125
+    help: str = None,
     shorthand: str = None,
 ) -> None:
     """Add a boolean flag to a parser inplace.
@@ -43,7 +44,9 @@ def boolean_flag(
     names = ["--" + name]
     if shorthand is not None:
         names.append("-" + shorthand)
-    parser.add_argument(*names, action="store_true", default=default, dest=dest, help=help)
+    parser.add_argument(
+        *names, action="store_true", default=default, dest=dest, help=help
+    )
     parser.add_argument("--no-" + name, action="store_false", dest=dest)
 
 
@@ -53,17 +56,22 @@ def set_global_seed(seed: int) -> None:
     Args:
         seed: random seed
     """
+    os.environ["PYTHONHASHSEED"] = str(seed)
+
     random.seed(seed)
     np.random.seed(seed)
+
+    torch.manual_seed(seed)
+    if torch.cuda.is_available():
+        torch.cuda.manual_seed(seed)
+        torch.cuda.manual_seed_all(seed)
+
     try:
-        import torch
+        import torch_xla.core.xla_model as xm
     except ImportError:
         pass
     else:
-        torch.manual_seed(seed)
-        if torch.cuda.is_available():
-            torch.cuda.manual_seed(seed)
-            torch.cuda.manual_seed_all(seed)
+        xm.set_rng_state(seed)
 
 
 def maybe_recursive_call(
@@ -91,7 +99,7 @@ def maybe_recursive_call(
             r_args = None if recursive_args is None else recursive_args[k]
             r_kwargs = None if recursive_kwargs is None else recursive_kwargs[k]
             result[k] = maybe_recursive_call(
-                v, method, recursive_args=r_args, recursive_kwargs=r_kwargs, **kwargs,
+                v, method, recursive_args=r_args, recursive_kwargs=r_kwargs, **kwargs
             )
         return result
 
@@ -105,12 +113,6 @@ def maybe_recursive_call(
         return method(object_or_dict, *r_args, **r_kwargs, **kwargs)
 
 
-def is_exception(ex: Any) -> bool:
-    """Check if the argument is of ``Exception`` type."""
-    result = (ex is not None) and isinstance(ex, BaseException)
-    return result
-
-
 def get_utcnow_time(format: str = None) -> str:
     """Return string with current utc time in chosen format.
 
@@ -126,41 +128,6 @@ def get_utcnow_time(format: str = None) -> str:
     return result
 
 
-def get_fn_default_params(fn: Callable[..., Any], exclude: List[str] = None):
-    """Return default parameters of Callable.
-
-    Args:
-        fn (Callable[..., Any]): target Callable
-        exclude: exclude list of parameters
-
-    Returns:
-        dict: contains default parameters of `fn`
-    """
-    argspec = inspect.getfullargspec(fn)
-    default_params = zip(argspec.args[-len(argspec.defaults) :], argspec.defaults)
-    if exclude is not None:
-        default_params = filter(lambda x: x[0] not in exclude, default_params)
-    default_params = dict(default_params)
-    return default_params
-
-
-def get_fn_argsnames(fn: Callable[..., Any], exclude: List[str] = None):
-    """Return parameter names of Callable.
-
-    Args:
-        fn (Callable[..., Any]): target Callable
-        exclude: exclude list of parameters
-
-    Returns:
-        list: contains parameter names of `fn`
-    """
-    argspec = inspect.getfullargspec(fn)
-    params = argspec.args + argspec.kwonlyargs
-    if exclude is not None:
-        params = list(filter(lambda x: x not in exclude, params))
-    return params
-
-
 def get_attr(obj: Any, key: str, inner_key: str = None) -> Any:
     """
     Alias for python `getattr` method. Useful for Callbacks preparation
@@ -214,56 +181,6 @@ def get_attr(obj: Any, key: str, inner_key: str = None) -> Any:
         return getattr(obj, key)[inner_key]
 
 
-def _get_key_str(dictionary: dict, key: Optional[Union[str, List[str]]]) -> Any:
-    return dictionary[key]
-
-
-def _get_key_list(dictionary: dict, key: Optional[Union[str, List[str]]]) -> Dict:
-    result = {name: dictionary[name] for name in key}
-    return result
-
-
-def _get_key_dict(dictionary: dict, key: Optional[Union[str, List[str]]]) -> Dict:
-    result = {key_out: dictionary[key_in] for key_in, key_out in key.items()}
-    return result
-
-
-def _get_key_none(dictionary: dict, key: Optional[Union[str, List[str]]]) -> Dict:
-    return {}
-
-
-def _get_key_all(dictionary: dict, key: Optional[Union[str, List[str]]]) -> Dict:
-    return dictionary
-
-
-def get_dictkey_auto_fn(key: Optional[Union[str, List[str]]]) -> Callable:
-    """Function generator for sub-dict preparation from dict based on predefined keys.
-
-    Args:
-        key: keys
-
-    Returns:
-        function
-
-    Raises:
-        NotImplementedError: if key is out of
-            `str`, `tuple`, `list`, `dict`, `None`
-    """
-    if isinstance(key, str):
-        if key == "__all__":
-            return _get_key_all
-        else:
-            return _get_key_str
-    elif isinstance(key, (list, tuple)):
-        return _get_key_list
-    elif isinstance(key, dict):
-        return _get_key_dict
-    elif key is None:
-        return _get_key_none
-    else:
-        raise NotImplementedError()
-
-
 def merge_dicts(*dicts: dict) -> dict:
     """Recursive dict merge.
     Instead of updating only top-level keys,
@@ -324,7 +241,9 @@ def _make_hashable(o):
     if isinstance(o, (tuple, list)):
         return tuple(((type(o).__name__, _make_hashable(e)) for e in o))
     if isinstance(o, dict):
-        return tuple(sorted((type(o).__name__, k, _make_hashable(v)) for k, v in o.items()))
+        return tuple(
+            sorted((type(o).__name__, k, _make_hashable(v)) for k, v in o.items())
+        )
     if isinstance(o, (set, frozenset)):
         return tuple(sorted((type(o).__name__, _make_hashable(e)) for e in o))
     return o
@@ -392,47 +311,14 @@ def make_tuple(tuple_like):
     Returns:
         tuple or list
     """
-    tuple_like = tuple_like if isinstance(tuple_like, (list, tuple)) else (tuple_like, tuple_like)
+    tuple_like = (
+        tuple_like if isinstance(tuple_like, (list, tuple)) else (tuple_like, tuple_like)
+    )
     return tuple_like
 
 
-def args_are_not_none(*args: Optional[Any]) -> bool:
-    """Check that all arguments are not ``None``.
-
-    Args:
-        *args: values  # noqa: RST213
-
-    Returns:
-         bool: True if all value were not None, False otherwise
-    """
-    if args is None:
-        return False
-
-    for arg in args:
-        if arg is None:
-            return False
-
-    return True
-
-
-def find_value_ids(it: Iterable[Any], value: Any) -> List[int]:
-    """
-    Args:
-        it: list of any
-        value: query element
-
-    Returns:
-        indices of the all elements equal x0
-    """
-    if isinstance(it, np.ndarray):
-        inds = list(np.where(it == value)[0])
-    else:  # could be very slow
-        inds = [i for i, el in enumerate(it) if el == value]
-    return inds
-
-
 def get_by_keys(dict_: dict, *keys: Any, default: Optional[T] = None) -> T:
-    """@TODO: docs."""
+    """Docs."""
     if not isinstance(dict_, dict):
         raise ValueError()
 
@@ -442,52 +328,17 @@ def get_by_keys(dict_: dict, *keys: Any, default: Optional[T] = None) -> T:
     return get_by_keys(dict_[key], *keys, default=default)
 
 
-def convert_labels2list(labels: Union[Tensor, List[int]]) -> List[int]:
-    """
-    This function allows to work with 2 types of indexing:
-    using a integer tensor and a list of indices.
-
-    Args:
-        labels: labels of batch samples
-
-    Returns:
-        labels of batch samples in the aligned format
-
-    Raises:
-        TypeError: if type of input labels is not tensor and list
-    """
-    if isinstance(labels, Tensor):
-        labels = labels.squeeze()
-        assert (len(labels.shape) == 1) and (
-            labels.dtype in [short, tint, long]
-        ), "Labels cannot be interpreted as indices."
-        labels_list = labels.tolist()
-    elif isinstance(labels, list):
-        labels_list = labels.copy()
-    else:
-        raise TypeError(f"Unexpected type of labels: {type(labels)}).")
-
-    return labels_list
-
-
 __all__ = [
     "boolean_flag",
-    "get_fn_default_params",
-    "get_fn_argsnames",
     "get_utcnow_time",
-    "is_exception",
     "maybe_recursive_call",
     "get_attr",
     "set_global_seed",
-    "get_dictkey_auto_fn",
     "merge_dicts",
     "flatten_dict",
     "get_hash",
     "get_short_hash",
-    "args_are_not_none",
     "make_tuple",
     "pairwise",
-    "find_value_ids",
     "get_by_keys",
-    "convert_labels2list",
 ]
