@@ -1,18 +1,17 @@
 from typing import Tuple, Union
-import logging
 
 import torch
 from torch import jit
 
-from catalyst.tools.forward_wrapper import ModelForwardWrapper
-from catalyst.typing import Model
-from catalyst.utils.torch import get_nn_from_ddp_module
-
-logger = logging.getLogger(__name__)
+from catalyst.extras.forward_wrapper import ModelForwardWrapper
+from catalyst.typing import TorchModel
+from catalyst.utils.distributed import get_nn_from_ddp_module
 
 
 def trace_model(
-    model: Model, batch: Union[Tuple[torch.Tensor], torch.Tensor], method_name: str = "forward",
+    model: TorchModel,
+    batch: Union[Tuple[torch.Tensor], torch.Tensor],
+    method_name: str = "forward",
 ) -> jit.ScriptModule:
     """Traces model using runner and batch.
 
