@@ -1,5 +1,6 @@
 # flake8: noqa
 import pytest
+
 import torch
 
 from catalyst.metrics.functional._misc import (
@@ -25,7 +26,7 @@ from catalyst.metrics.functional._misc import (
     ],
 )
 def test_get_binary_statistics(
-    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true,
+    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true
 ):
     tn, fp, fn, tp, support = get_binary_statistics(outputs, targets)
 
@@ -78,9 +79,9 @@ def test_get_binary_statistics(
     ],
 )
 def test_get_multiclass_statistics(
-    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true,
+    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true
 ):
-    tn, fp, fn, tp, support = get_multiclass_statistics(outputs, targets)
+    tn, fp, fn, tp, support, _ = get_multiclass_statistics(outputs, targets)
 
     assert torch.allclose(torch.tensor(tn_true).to(tn), tn)
     assert torch.allclose(torch.tensor(fp_true).to(fp), fp)
@@ -122,9 +123,9 @@ def test_get_multiclass_statistics(
     ],
 )
 def test_get_multilabel_statistics(
-    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true,
+    outputs, targets, tn_true, fp_true, fn_true, tp_true, support_true
 ):
-    tn, fp, fn, tp, support = get_multilabel_statistics(outputs, targets)
+    tn, fp, fn, tp, support, _ = get_multilabel_statistics(outputs, targets)
 
     assert torch.allclose(torch.tensor(tn_true).to(tn), tn)
     assert torch.allclose(torch.tensor(fp_true).to(fp), fp)
