@@ -3,15 +3,20 @@ from typing import Iterable, Union
 
 import numpy as np
 import pytest
+
 import torch
 
-from catalyst.metrics._additive import AdditiveValueMetric
+from catalyst.metrics._additive import AdditiveMetric
 
 
 @pytest.mark.parametrize(
     "values_list,num_samples_list,true_values_list",
     (
-        ([1, 2, 3, 4, 5], [100, 200, 300, 400, 500], [1, 1.666667, 2.333333, 3, 3.666667]),
+        (
+            [1, 2, 3, 4, 5],
+            [100, 200, 300, 400, 500],
+            [1, 1.666667, 2.333333, 3, 3.666667],
+        ),
         ([1, 0, 2, 3], [10, 5, 15, 25], [1, 0.666667, 1.333333, 2.090909]),
         (
             [100, 10, 1000, 10000, 0],
@@ -33,8 +38,10 @@ def test_additive_mean(
         num_samples_list: list of num_samples
         true_values_list: list of metric intermediate value
     """
-    metric = AdditiveValueMetric()
-    for value, num_samples, true_value in zip(values_list, num_samples_list, true_values_list):
+    metric = AdditiveMetric()
+    for value, num_samples, true_value in zip(
+        values_list, num_samples_list, true_values_list
+    ):
         metric.update(value=value, num_samples=num_samples)
         mean, _ = metric.compute()
         assert np.isclose(mean, true_value)
@@ -43,7 +50,11 @@ def test_additive_mean(
 @pytest.mark.parametrize(
     "values_list,num_samples_list,true_values_list",
     (
-        ([1, 2, 3, 4, 5], [100, 200, 300, 400, 500], [0, 0.472192, 0.745978, 1.0005, 1.247635]),
+        (
+            [1, 2, 3, 4, 5],
+            [100, 200, 300, 400, 500],
+            [0, 0.472192, 0.745978, 1.0005, 1.247635],
+        ),
         ([1, 0, 2, 3], [10, 5, 15, 25], [0, 0.48795, 0.758098, 1.005038]),
         (
             [100, 10, 1000, 10000, 0],
@@ -65,8 +76,10 @@ def test_additive_std(
         num_samples_list: list of num_samples
         true_values_list: list of metric intermediate value
     """
-    metric = AdditiveValueMetric()
-    for value, num_samples, true_value in zip(values_list, num_samples_list, true_values_list):
+    metric = AdditiveMetric()
+    for value, num_samples, true_value in zip(
+        values_list, num_samples_list, true_values_list
+    ):
         metric.update(value=value, num_samples=num_samples)
         _, std = metric.compute()
         assert np.isclose(std, true_value)
@@ -102,10 +115,12 @@ def test_additive_mode(
         values_list: list of values to update metric
         num_samples_list: list of num_samples
         true_values_list: list of metric intermediate value
-        mode: `AdditiveValueMetric` mode
+        mode: `AdditiveMetric` mode
     """
-    metric = AdditiveValueMetric(mode=mode)
-    for value, num_samples, true_value in zip(values_list, num_samples_list, true_values_list):
+    metric = AdditiveMetric(mode=mode)
+    for value, num_samples, true_value in zip(
+        values_list, num_samples_list, true_values_list
+    ):
         metric.update(value=value, num_samples=num_samples)
         mean, _ = metric.compute()
         assert np.isclose(mean, true_value)
